@@ -6,13 +6,13 @@ from __future__ import unicode_literals
 # The *_FORMAT strings use the Django date format syntax,
 # see http://docs.djangoproject.com/en/dev/ref/templates/builtins/#date
 DATE_FORMAT = r'j \d\e F \d\e Y'
-TIME_FORMAT = 'G:i'
+TIME_FORMAT = 'G:i:s'
 DATETIME_FORMAT = r'j \d\e F \d\e Y \a \l\e\s G:i'
 YEAR_MONTH_FORMAT = r'F \d\e\l Y'
 MONTH_DAY_FORMAT = r'j \d\e F'
 SHORT_DATE_FORMAT = 'd/m/Y'
 SHORT_DATETIME_FORMAT = 'd/m/Y G:i'
-FIRST_DAY_OF_WEEK = 1  # Monday
+FIRST_DAY_OF_WEEK = 1 # Monday
 
 # The *_INPUT_FORMATS strings use the Python strftime format syntax,
 # see http://docs.python.org/library/datetime.html#strftime-strptime-behavior
@@ -31,3 +31,4 @@ DATETIME_INPUT_FORMATS = (
 DECIMAL_SEPARATOR = ','
 THOUSAND_SEPARATOR = '.'
 NUMBER_GROUPING = 3
+
