@@ -5,20 +5,20 @@ from __future__ import unicode_literals
 
 # The *_FORMAT strings use the Django date format syntax,
 # see http://docs.djangoproject.com/en/dev/ref/templates/builtins/#date
-DATE_FORMAT = r'Y\k\o N j\a'
-TIME_FORMAT = 'H:i'
-# DATETIME_FORMAT =
-# YEAR_MONTH_FORMAT =
-# MONTH_DAY_FORMAT =
+DATE_FORMAT = r'Yeko M\re\n d\a'
+TIME_FORMAT = 'H:i:s'
+# DATETIME_FORMAT = 
+# YEAR_MONTH_FORMAT = 
+# MONTH_DAY_FORMAT = 
 SHORT_DATE_FORMAT = 'Y M j'
-# SHORT_DATETIME_FORMAT =
-# FIRST_DAY_OF_WEEK =
+# SHORT_DATETIME_FORMAT = 
+# FIRST_DAY_OF_WEEK = 
 
 # The *_INPUT_FORMATS strings use the Python strftime format syntax,
 # see http://docs.python.org/library/datetime.html#strftime-strptime-behavior
-# DATE_INPUT_FORMATS =
-# TIME_INPUT_FORMATS =
-# DATETIME_INPUT_FORMATS =
+# DATE_INPUT_FORMATS = 
+# TIME_INPUT_FORMATS = 
+# DATETIME_INPUT_FORMATS = 
 DECIMAL_SEPARATOR = ','
 THOUSAND_SEPARATOR = '.'
-# NUMBER_GROUPING =
+# NUMBER_GROUPING = 
