@@ -7,19 +7,31 @@ from __future__ import unicode_literals
 # Python, ctypes and types dependencies.
 from ctypes import addressof, byref, c_double
 
+from django.contrib.gis import memoryview
+# super-class for mutable list behavior
+from django.contrib.gis.geos.mutable_list import ListMixin
+
 from django.contrib.gis.gdal.error import SRSException
-from django.contrib.gis.geometry.regex import hex_regex, json_regex, wkt_regex
-from django.contrib.gis.geos import prototypes as capi
+
+# GEOS-related dependencies.
 from django.contrib.gis.geos.base import GEOSBase, gdal
 from django.contrib.gis.geos.coordseq import GEOSCoordSeq
 from django.contrib.gis.geos.error import GEOSException, GEOSIndexError
-from django.contrib.gis.geos.libgeos import GEOM_PTR
+from django.contrib.gis.geos.libgeos import GEOM_PTR, GEOS_PREPARE
 from django.contrib.gis.geos.mutable_list import ListMixin
+
+# All other functions in this module come from the ctypes
+# prototypes module -- which handles all interaction with
+# the underlying GEOS library.
+from django.contrib.gis.geos import prototypes as capi
+
 # These functions provide access to a thread-local instance
 # of their corresponding GEOS I/O class.
-from django.contrib.gis.geos.prototypes.io import (
-    ewkb_w, wkb_r, wkb_w, wkt_r, wkt_w,
-)
+from django.contrib.gis.geos.prototypes.io import wkt_r, wkt_w, wkb_r, wkb_w, ewkb_w
+
+# For recognizing geometry input.
+from django.contrib.gis.geometry.regex import hex_regex, wkt_regex, json_regex
+
 from django.utils import six
 from django.utils.encoding import force_bytes, force_text
 
@@ -33,6 +45,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
 
     ptr_type = GEOM_PTR
 
+    #### Python 'magic' routines ####
     def __init__(self, geo_input, srid=None):
         """
         The base constructor for GEOS geometry objects, and may take the
@@ -54,23 +67,20 @@ class GEOSGeometry(GEOSBase, ListMixin):
             wkt_m = wkt_regex.match(geo_input)
             if wkt_m:
                 # Handling WKT input.
-                if wkt_m.group('srid'):
-                    srid = int(wkt_m.group('srid'))
+                if wkt_m.group('srid'): srid = int(wkt_m.group('srid'))
                 g = wkt_r().read(force_bytes(wkt_m.group('wkt')))
             elif hex_regex.match(geo_input):
                 # Handling HEXEWKB input.
                 g = wkb_r().read(force_bytes(geo_input))
-            elif json_regex.match(geo_input):
+            elif gdal.HAS_GDAL and json_regex.match(geo_input):
                 # Handling GeoJSON input.
-                if not gdal.HAS_GDAL:
-                    raise ValueError('Initializing geometry from JSON input requires GDAL.')
                 g = wkb_r().read(gdal.OGRGeometry(geo_input).wkb)
             else:
                 raise ValueError('String or unicode input unrecognized as WKT EWKT, and HEXEWKB.')
         elif isinstance(geo_input, GEOM_PTR):
-            # When the input is a pointer to a geometry (GEOM_PTR).
+            # When the input is a pointer to a geomtry (GEOM_PTR).
             g = geo_input
-        elif isinstance(geo_input, six.memoryview):
+        elif isinstance(geo_input, memoryview):
             # When the input is a buffer (WKB).
             g = wkb_r().read(geo_input)
         elif isinstance(geo_input, GEOSGeometry):
@@ -79,7 +89,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
             # Invalid geometry type.
             raise TypeError('Improper geometry input type: %s' % str(type(geo_input)))
 
-        if g:
+        if bool(g):
             # Setting the pointer object with a valid pointer.
             self.ptr = g
         else:
@@ -91,8 +101,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
     def _post_init(self, srid):
         "Helper routine for performing post-initialization setup."
         # Setting the SRID, if given.
-        if srid and isinstance(srid, int):
-            self.srid = srid
+        if srid and isinstance(srid, int): self.srid = srid
 
         # Setting the class type (e.g., Point, Polygon, etc.)
         self.__class__ = GEOS_CLASSES[self.geom_typeid]
@@ -106,8 +115,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
         Destroys this Geometry; in other words, frees the memory used by the
         GEOS C++ object.
         """
-        if self._ptr and capi:
-            capi.destroy_geom(self._ptr)
+        if self._ptr: capi.destroy_geom(self._ptr)
 
     def __copy__(self):
         """
@@ -125,8 +133,8 @@ class GEOSGeometry(GEOSBase, ListMixin):
         return self.clone()
 
     def __str__(self):
-        "EWKT is used for the string representation."
-        return self.ewkt
+        "WKT is used for the string representation."
+        return self.wkt
 
     def __repr__(self):
         "Short-hand representation because WKT may be very large."
@@ -141,9 +149,8 @@ class GEOSGeometry(GEOSBase, ListMixin):
     def __setstate__(self, state):
         # Instantiating from the tuple state that was pickled.
         wkb, srid = state
-        ptr = wkb_r().read(six.memoryview(wkb))
-        if not ptr:
-            raise GEOSException('Invalid Geometry loaded from pickled state.')
+        ptr = wkb_r().read(memoryview(wkb))
+        if not ptr: raise GEOSException('Invalid Geometry loaded from pickled state.')
         self.ptr = ptr
         self._post_init(srid)
 
@@ -164,7 +171,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
         "The not equals operator."
         return not (self == other)
 
-    # ### Geometry set-like operations ###
+    ### Geometry set-like operations ###
     # Thanks to Sean Gillies for inspiration:
     #  http://lists.gispython.org/pipermail/community/2007-July/001034.html
     # g = g1 | g2
@@ -187,7 +194,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
         "Return the symmetric difference of this Geometry and the other."
         return self.sym_difference(other)
 
-    # #### Coordinate Sequence Routines ####
+    #### Coordinate Sequence Routines ####
     @property
     def has_cs(self):
         "Returns True if this Geometry has a coordinate sequence, False if not."
@@ -210,7 +217,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
         if self.has_cs:
             return self._cs.clone()
 
-    # #### Geometry Info ####
+    #### Geometry Info ####
     @property
     def geom_type(self):
         "Returns a string representing the Geometry type, e.g. 'Polygon'"
@@ -245,7 +252,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
         "Converts this Geometry to normal form (or canonical form)."
         return capi.geos_normalize(self.ptr)
 
-    # #### Unary predicates ####
+    #### Unary predicates ####
     @property
     def empty(self):
         """
@@ -279,9 +286,11 @@ class GEOSGeometry(GEOSBase, ListMixin):
         """
         Returns a string containing the reason for any invalidity.
         """
+        if not GEOS_PREPARE:
+            raise GEOSException('Upgrade GEOS to 3.1 to get validity reason.')
         return capi.geos_isvalidreason(self.ptr).decode()
 
-    # #### Binary predicates. ####
+    #### Binary predicates. ####
     def contains(self, other):
         "Returns true if other.within(this) returns true."
         return capi.geos_contains(self.ptr, other.ptr)
@@ -349,31 +358,28 @@ class GEOSGeometry(GEOSBase, ListMixin):
         """
         return capi.geos_within(self.ptr, other.ptr)
 
-    # #### SRID Routines ####
+    #### SRID Routines ####
     def get_srid(self):
         "Gets the SRID for the geometry, returns None if no SRID is set."
         s = capi.geos_get_srid(self.ptr)
-        if s == 0:
-            return None
-        else:
-            return s
+        if s == 0: return None
+        else: return s
 
     def set_srid(self, srid):
         "Sets the SRID for the geometry."
         capi.geos_set_srid(self.ptr, srid)
     srid = property(get_srid, set_srid)
 
-    # #### Output Routines ####
+    #### Output Routines ####
     @property
     def ewkt(self):
         """
-        Returns the EWKT (SRID + WKT) of the Geometry. Note that Z values
-        are only included in this representation if GEOS >= 3.3.0.
+        Returns the EWKT (WKT + SRID) of the Geometry.  Note that Z values
+        are *not* included in this representation because GEOS does not yet
+        support serializing them.
         """
-        if self.get_srid():
-            return 'SRID=%s;%s' % (self.srid, self.wkt)
-        else:
-            return self.wkt
+        if self.get_srid(): return 'SRID=%s;%s' % (self.srid, self.wkt)
+        else: return self.wkt
 
     @property
     def wkt(self):
@@ -398,6 +404,9 @@ class GEOSGeometry(GEOSBase, ListMixin):
         extension of the WKB specification that includes SRID value that are
         a part of this geometry.
         """
+        if self.hasz and not GEOS_PREPARE:
+            # See: http://trac.osgeo.org/geos/ticket/216
+            raise GEOSException('Upgrade GEOS to 3.1 to get valid 3D HEXEWKB.')
         return ewkb_w(3 if self.hasz else 2).write_hex(self)
 
     @property
@@ -427,6 +436,9 @@ class GEOSGeometry(GEOSBase, ListMixin):
         This is an extension of the WKB specification that includes any SRID
         value that are a part of this geometry.
         """
+        if self.hasz and not GEOS_PREPARE:
+            # See: http://trac.osgeo.org/geos/ticket/216
+            raise GEOSException('Upgrade GEOS to 3.1 to get valid 3D EWKB.')
         return ewkb_w(3 if self.hasz else 2).write(self)
 
     @property
@@ -441,9 +453,12 @@ class GEOSGeometry(GEOSBase, ListMixin):
         Returns a PreparedGeometry corresponding to this geometry -- it is
         optimized for the contains, intersects, and covers operations.
         """
-        return PreparedGeometry(self)
+        if GEOS_PREPARE:
+            return PreparedGeometry(self)
+        else:
+            raise GEOSException('GEOS 3.1+ required for prepared geometry support.')
 
-    # #### GDAL-specific output routines ####
+    #### GDAL-specific output routines ####
     @property
     def ogr(self):
         "Returns the OGR Geometry for this Geometry."
@@ -514,7 +529,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
         else:
             raise GEOSException('Transformed WKB was invalid.')
 
-    # #### Topology Routines ####
+    #### Topology Routines ####
     def _topology(self, gptr):
         "Helper routine to return Geometry from the given pointer."
         return GEOSGeometry(gptr, srid=self.srid)
@@ -566,11 +581,15 @@ class GEOSGeometry(GEOSBase, ListMixin):
     def interpolate(self, distance):
         if not isinstance(self, (LineString, MultiLineString)):
             raise TypeError('interpolate only works on LineString and MultiLineString geometries')
+        if not hasattr(capi, 'geos_interpolate'):
+            raise NotImplementedError('interpolate requires GEOS 3.2+')
         return self._topology(capi.geos_interpolate(self.ptr, distance))
 
     def interpolate_normalized(self, distance):
         if not isinstance(self, (LineString, MultiLineString)):
             raise TypeError('interpolate only works on LineString and MultiLineString geometries')
+        if not hasattr(capi, 'geos_interpolate_normalized'):
+            raise NotImplementedError('interpolate_normalized requires GEOS 3.2+')
         return self._topology(capi.geos_interpolate_normalized(self.ptr, distance))
 
     def intersection(self, other):
@@ -587,6 +606,8 @@ class GEOSGeometry(GEOSBase, ListMixin):
             raise TypeError('locate_point argument must be a Point')
         if not isinstance(self, (LineString, MultiLineString)):
             raise TypeError('locate_point only works on LineString and MultiLineString geometries')
+        if not hasattr(capi, 'geos_project'):
+            raise NotImplementedError('geos_project requires GEOS 3.2+')
         return capi.geos_project(self.ptr, point.ptr)
 
     def project_normalized(self, point):
@@ -594,6 +615,8 @@ class GEOSGeometry(GEOSBase, ListMixin):
             raise TypeError('locate_point argument must be a Point')
         if not isinstance(self, (LineString, MultiLineString)):
             raise TypeError('locate_point only works on LineString and MultiLineString geometries')
+        if not hasattr(capi, 'geos_project_normalized'):
+            raise NotImplementedError('project_normalized requires GEOS 3.2+')
         return capi.geos_project_normalized(self.ptr, point.ptr)
 
     def relate(self, other):
@@ -628,7 +651,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
         "Returns a Geometry representing all the points in this Geometry and other."
         return self._topology(capi.geos_union(self.ptr, other.ptr))
 
-    # #### Other Routines ####
+    #### Other Routines ####
     @property
     def area(self):
         "Returns the area of the Geometry."
@@ -663,7 +686,7 @@ class GEOSGeometry(GEOSBase, ListMixin):
     def length(self):
         """
         Returns the length of this Geometry (e.g., 0 for point, or the
-        circumference of a Polygon).
+        circumfrence of a Polygon).
         """
         return capi.geos_length(self.ptr, byref(c_double()))
 
@@ -671,22 +694,22 @@ class GEOSGeometry(GEOSBase, ListMixin):
         "Clones this Geometry."
         return GEOSGeometry(capi.geom_clone(self.ptr), srid=self.srid)
 
-
 # Class mapping dictionary.  Has to be at the end to avoid import
 # conflicts with GEOSGeometry.
-from django.contrib.gis.geos.linestring import LineString, LinearRing  # isort:skip
-from django.contrib.gis.geos.point import Point                     # isort:skip
-from django.contrib.gis.geos.polygon import Polygon                 # isort:skip
-from django.contrib.gis.geos.collections import (                   # isort:skip
-    GeometryCollection, MultiPoint, MultiLineString, MultiPolygon)
-from django.contrib.gis.geos.prepared import PreparedGeometry       # isort:skip
-GEOS_CLASSES = {
-    0: Point,
-    1: LineString,
-    2: LinearRing,
-    3: Polygon,
-    4: MultiPoint,
-    5: MultiLineString,
-    6: MultiPolygon,
-    7: GeometryCollection,
-}
+from django.contrib.gis.geos.linestring import LineString, LinearRing
+from django.contrib.gis.geos.point import Point
+from django.contrib.gis.geos.polygon import Polygon
+from django.contrib.gis.geos.collections import GeometryCollection, MultiPoint, MultiLineString, MultiPolygon
+GEOS_CLASSES = {0 : Point,
+                1 : LineString,
+                2 : LinearRing,
+                3 : Polygon,
+                4 : MultiPoint,
+                5 : MultiLineString,
+                6 : MultiPolygon,
+                7 : GeometryCollection,
+                }
+
+# If supported, import the PreparedGeometry class.
+if GEOS_PREPARE:
+    from django.contrib.gis.geos.prepared import PreparedGeometry
