@@ -1,8 +1,6 @@
 from django.contrib.gis.db import models
 
-
 class AllOGRFields(models.Model):
-
     f_decimal = models.FloatField()
     f_float = models.FloatField()
     f_int = models.IntegerField()
@@ -11,9 +9,5 @@ class AllOGRFields(models.Model):
     f_datetime = models.DateTimeField()
     f_time = models.TimeField()
     geom = models.PolygonField()
-    point = models.PointField()
 
     objects = models.GeoManager()
-
-    class Meta:
-        app_label = 'inspectapp'
