@@ -4,84 +4,60 @@
  vector files (e.g. SHP files) to Geographic-enabled Django models.
 
  For more information, please consult the GeoDjango documentation:
-   https://docs.djangoproject.com/en/dev/ref/contrib/gis/layermapping/
+   http://geodjango.org/docs/layermapping.html
 """
 import sys
-from decimal import Decimal, InvalidOperation as DecimalInvalidOperation
-from pathlib import Path
-
+from decimal import Decimal
+from django.core.exceptions import ObjectDoesNotExist
+from django.db import connections, router
 from django.contrib.gis.db.models import GeometryField
-from django.contrib.gis.gdal import (
-    CoordTransform, DataSource, GDALException, OGRGeometry, OGRGeomType,
-    SpatialReference,
-)
+from django.contrib.gis.gdal import (CoordTransform, DataSource,
+    OGRException, OGRGeometry, OGRGeomType, SpatialReference)
 from django.contrib.gis.gdal.field import (
-    OFTDate, OFTDateTime, OFTInteger, OFTInteger64, OFTReal, OFTString,
-    OFTTime,
-)
-from django.core.exceptions import FieldDoesNotExist, ObjectDoesNotExist
-from django.db import connections, models, router, transaction
-from django.utils.encoding import force_str
+    OFTDate, OFTDateTime, OFTInteger, OFTReal, OFTString, OFTTime)
+from django.db import models, transaction
+from django.utils import six
+from django.utils.encoding import force_text
 
 
 # LayerMapping exceptions.
-class LayerMapError(Exception):
-    pass
+class LayerMapError(Exception): pass
+class InvalidString(LayerMapError): pass
+class InvalidDecimal(LayerMapError): pass
+class InvalidInteger(LayerMapError): pass
+class MissingForeignKey(LayerMapError): pass
 
-
-class InvalidString(LayerMapError):
-    pass
-
-
-class InvalidDecimal(LayerMapError):
-    pass
-
-
-class InvalidInteger(LayerMapError):
-    pass
-
-
-class MissingForeignKey(LayerMapError):
-    pass
-
-
-class LayerMapping:
+class LayerMapping(object):
     "A class that maps OGR Layers to GeoDjango Models."
 
     # Acceptable 'base' types for a multi-geometry type.
-    MULTI_TYPES = {
-        1: OGRGeomType('MultiPoint'),
-        2: OGRGeomType('MultiLineString'),
-        3: OGRGeomType('MultiPolygon'),
-        OGRGeomType('Point25D').num: OGRGeomType('MultiPoint25D'),
-        OGRGeomType('LineString25D').num: OGRGeomType('MultiLineString25D'),
-        OGRGeomType('Polygon25D').num: OGRGeomType('MultiPolygon25D'),
-    }
+    MULTI_TYPES = {1 : OGRGeomType('MultiPoint'),
+                   2 : OGRGeomType('MultiLineString'),
+                   3 : OGRGeomType('MultiPolygon'),
+                   OGRGeomType('Point25D').num : OGRGeomType('MultiPoint25D'),
+                   OGRGeomType('LineString25D').num : OGRGeomType('MultiLineString25D'),
+                   OGRGeomType('Polygon25D').num : OGRGeomType('MultiPolygon25D'),
+                   }
+
     # Acceptable Django field types and corresponding acceptable OGR
     # counterparts.
     FIELD_TYPES = {
-        models.AutoField: OFTInteger,
-        models.BigAutoField: OFTInteger64,
-        models.SmallAutoField: OFTInteger,
-        models.BooleanField: (OFTInteger, OFTReal, OFTString),
-        models.IntegerField: (OFTInteger, OFTReal, OFTString),
-        models.FloatField: (OFTInteger, OFTReal),
-        models.DateField: OFTDate,
-        models.DateTimeField: OFTDateTime,
-        models.EmailField: OFTString,
-        models.TimeField: OFTTime,
-        models.DecimalField: (OFTInteger, OFTReal),
-        models.CharField: OFTString,
-        models.SlugField: OFTString,
-        models.TextField: OFTString,
-        models.URLField: OFTString,
-        models.UUIDField: OFTString,
-        models.BigIntegerField: (OFTInteger, OFTReal, OFTString),
-        models.SmallIntegerField: (OFTInteger, OFTReal, OFTString),
-        models.PositiveBigIntegerField: (OFTInteger, OFTReal, OFTString),
-        models.PositiveIntegerField: (OFTInteger, OFTReal, OFTString),
-        models.PositiveSmallIntegerField: (OFTInteger, OFTReal, OFTString),
-    }
+        models.AutoField : OFTInteger,
+        models.IntegerField : (OFTInteger, OFTReal, OFTString),
+        models.FloatField : (OFTInteger, OFTReal),
+        models.DateField : OFTDate,
+        models.DateTimeField : OFTDateTime,
+        models.EmailField : OFTString,
+        models.TimeField : OFTTime,
+        models.DecimalField : (OFTInteger, OFTReal),
+        models.CharField : OFTString,
+        models.SlugField : OFTString,
+        models.TextField : OFTString,
+        models.URLField : OFTString,
+        models.BigIntegerField : (OFTInteger, OFTReal, OFTString),
+        models.SmallIntegerField : (OFTInteger, OFTReal, OFTString),
+        models.PositiveSmallIntegerField : (OFTInteger, OFTReal, OFTString),
+        }
 
     def __init__(self, model, data, mapping, layer=0,
                  source_srs=None, encoding='utf-8',
@@ -94,7 +70,7 @@ class LayerMapping:
         argument usage.
         """
         # Getting the DataSource and the associated Layer.
-        if isinstance(data, (str, Path)):
+        if isinstance(data, six.string_types):
             self.ds = DataSource(data, encoding=encoding)
         else:
             self.ds = data
@@ -107,16 +83,16 @@ class LayerMapping:
         self.mapping = mapping
         self.model = model
 
-        # Checking the layer -- initialization of the object will fail if
+        # Checking the layer -- intitialization of the object will fail if
         # things don't check out before hand.
         self.check_layer()
 
         # Getting the geometry column associated with the model (an
         # exception will be raised if there is no geometry column).
-        if connections[self.using].features.supports_transform:
-            self.geo_field = self.geometry_field()
-        else:
+        if self.spatial_backend.mysql:
             transform = False
+        else:
+            self.geo_field = self.geometry_field()
 
         # Checking the source spatial reference system, and getting
         # the coordinate transformation object (unless the `transform`
@@ -139,7 +115,7 @@ class LayerMapping:
 
         if unique:
             self.check_unique(unique)
-            transaction_mode = 'autocommit'  # Has to be set to autocommit.
+            transaction_mode = 'autocommit' # Has to be set to autocommit.
             self.unique = unique
         else:
             self.unique = None
@@ -154,9 +130,9 @@ class LayerMapping:
         else:
             raise LayerMapError('Unrecognized transaction mode: %s' % transaction_mode)
 
-    # #### Checking routines used during initialization ####
+    #### Checking routines used during initialization ####
     def check_fid_range(self, fid_range):
-        "Check the `fid_range` keyword."
+        "This checks the `fid_range` keyword."
         if fid_range:
             if isinstance(fid_range, (tuple, list)):
                 return slice(*fid_range)
@@ -169,9 +145,9 @@ class LayerMapping:
 
     def check_layer(self):
         """
-        Check the Layer metadata and ensure that it's compatible with the
-        mapping information and model. Unlike previous revisions, there is no
-        need to increment through each feature in the Layer.
+        This checks the Layer metadata, and ensures that it is compatible
+        with the mapping information and model.  Unlike previous revisions,
+        there is no need to increment through each feature in the Layer.
         """
         # The geometry field of the model is set here.
         # TODO: Support more than one geometry field / model.  However, this
@@ -199,7 +175,7 @@ class LayerMapping:
             # for the given field name in the mapping.
             try:
                 model_field = self.model._meta.get_field(field_name)
-            except FieldDoesNotExist:
+            except models.fields.FieldDoesNotExist:
                 raise LayerMapError('Given mapping field "%s" not in given Model fields.' % field_name)
 
             # Getting the string name for the Django field class (e.g., 'PointField').
@@ -217,7 +193,7 @@ class LayerMapping:
                         gtype = OGRGeomType(ogr_name + '25D')
                     else:
                         gtype = OGRGeomType(ogr_name)
-                except GDALException:
+                except OGRException:
                     raise LayerMapError('Invalid mapping for GeometryField "%s".' % field_name)
 
                 # Making sure that the OGR Layer's Geometry is compatible.
@@ -236,12 +212,12 @@ class LayerMapping:
             elif isinstance(model_field, models.ForeignKey):
                 if isinstance(ogr_name, dict):
                     # Is every given related model mapping field in the Layer?
-                    rel_model = model_field.remote_field.model
+                    rel_model = model_field.rel.to
                     for rel_name, ogr_field in ogr_name.items():
                         idx = check_ogr_fld(ogr_field)
                         try:
-                            rel_model._meta.get_field(rel_name)
-                        except FieldDoesNotExist:
+                            rel_field = rel_model._meta.get_field(rel_name)
+                        except models.fields.FieldDoesNotExist:
                             raise LayerMapError('ForeignKey mapping field "%s" not in %s fields.' %
                                                 (rel_name, rel_model.__class__.__name__))
                     fields_val = rel_model
@@ -249,7 +225,7 @@ class LayerMapping:
                     raise TypeError('ForeignKey mapping must be of dictionary type.')
             else:
                 # Is the model field type supported by LayerMapping?
-                if model_field.__class__ not in self.FIELD_TYPES:
+                if not model_field.__class__ in self.FIELD_TYPES:
                     raise LayerMapError('Django field type "%s" has no OGR mapping (yet).' % fld_name)
 
                 # Is the OGR field in the Layer?
@@ -265,13 +241,13 @@ class LayerMapping:
             self.fields[field_name] = fields_val
 
     def check_srs(self, source_srs):
-        "Check the compatibility of the given spatial reference object."
+        "Checks the compatibility of the given spatial reference object."
 
         if isinstance(source_srs, SpatialReference):
             sr = source_srs
         elif isinstance(source_srs, self.spatial_backend.spatial_ref_sys()):
             sr = source_srs.srs
-        elif isinstance(source_srs, (int, str)):
+        elif isinstance(source_srs, (int, six.string_types)):
             sr = SpatialReference(source_srs)
         else:
             # Otherwise just pulling the SpatialReference from the layer
@@ -283,24 +259,22 @@ class LayerMapping:
             return sr
 
     def check_unique(self, unique):
-        "Check the `unique` keyword parameter -- may be a sequence or string."
+        "Checks the `unique` keyword parameter -- may be a sequence or string."
         if isinstance(unique, (list, tuple)):
             # List of fields to determine uniqueness with
             for attr in unique:
-                if attr not in self.mapping:
-                    raise ValueError
-        elif isinstance(unique, str):
+                if not attr in self.mapping: raise ValueError
+        elif isinstance(unique, six.string_types):
             # Only a single field passed in.
-            if unique not in self.mapping:
-                raise ValueError
+            if unique not in self.mapping: raise ValueError
         else:
             raise TypeError('Unique keyword argument must be set with a tuple, list, or string.')
 
-    # Keyword argument retrieval routines ####
+    #### Keyword argument retrieval routines ####
     def feature_kwargs(self, feat):
         """
-        Given an OGR Feature, return a dictionary of keyword arguments for
-        constructing the mapped model.
+        Given an OGR Feature, this will return a dictionary of keyword arguments
+        for constructing the mapped model.
         """
         # The keyword arguments for model construction.
         kwargs = {}
@@ -314,7 +288,7 @@ class LayerMapping:
                 # Verify OGR geometry.
                 try:
                     val = self.verify_geom(feat.geom, model_field)
-                except GDALException:
+                except OGRException:
                     raise LayerMapError('Could not retrieve geometry from feature.')
             elif isinstance(model_field, models.base.ModelBase):
                 # The related _model_, not a field was passed in -- indicating
@@ -332,43 +306,44 @@ class LayerMapping:
 
     def unique_kwargs(self, kwargs):
         """
-        Given the feature keyword arguments (from `feature_kwargs`), construct
-        and return the uniqueness keyword arguments -- a subset of the feature
-        kwargs.
+        Given the feature keyword arguments (from `feature_kwargs`) this routine
+        will construct and return the uniqueness keyword arguments -- a subset
+        of the feature kwargs.
         """
-        if isinstance(self.unique, str):
-            return {self.unique: kwargs[self.unique]}
+        if isinstance(self.unique, six.string_types):
+            return {self.unique : kwargs[self.unique]}
         else:
-            return {fld: kwargs[fld] for fld in self.unique}
+            return dict((fld, kwargs[fld]) for fld in self.unique)
 
-    # #### Verification routines used in constructing model keyword arguments. ####
+    #### Verification routines used in constructing model keyword arguments. ####
     def verify_ogr_field(self, ogr_field, model_field):
         """
-        Verify if the OGR Field contents are acceptable to the model field. If
-        they are, return the verified value, otherwise raise an exception.
+        Verifies if the OGR Field contents are acceptable to the Django
+        model field.  If they are, the verified value is returned,
+        otherwise the proper exception is raised.
         """
         if (isinstance(ogr_field, OFTString) and
-                isinstance(model_field, (models.CharField, models.TextField))):
-            if self.encoding and ogr_field.value is not None:
+            isinstance(model_field, (models.CharField, models.TextField))):
+            if self.encoding:
                 # The encoding for OGR data sources may be specified here
                 # (e.g., 'cp437' for Census Bureau boundary files).
-                val = force_str(ogr_field.value, self.encoding)
+                val = force_text(ogr_field.value, self.encoding)
             else:
                 val = ogr_field.value
-            if model_field.max_length and val is not None and len(val) > model_field.max_length:
-                raise InvalidString('%s model field maximum string length is %s, given %s characters.' %
-                                    (model_field.name, model_field.max_length, len(val)))
+                if model_field.max_length and len(val) > model_field.max_length:
+                    raise InvalidString('%s model field maximum string length is %s, given %s characters.' %
+                                        (model_field.name, model_field.max_length, len(val)))
         elif isinstance(ogr_field, OFTReal) and isinstance(model_field, models.DecimalField):
             try:
                 # Creating an instance of the Decimal value to use.
                 d = Decimal(str(ogr_field.value))
-            except DecimalInvalidOperation:
+            except:
                 raise InvalidDecimal('Could not construct decimal from: %s' % ogr_field.value)
 
             # Getting the decimal value as a tuple.
             dtup = d.as_tuple()
             digits = dtup[1]
-            d_idx = dtup[2]  # index where the decimal is
+            d_idx = dtup[2] # index where the decimal is
 
             # Maximum amount of precision, or digits to the left of the decimal.
             max_prec = model_field.max_digits - model_field.decimal_places
@@ -383,17 +358,14 @@ class LayerMapping:
             # If we have more than the maximum digits allowed, then throw an
             # InvalidDecimal exception.
             if n_prec > max_prec:
-                raise InvalidDecimal(
-                    'A DecimalField with max_digits %d, decimal_places %d must '
-                    'round to an absolute value less than 10^%d.' %
-                    (model_field.max_digits, model_field.decimal_places, max_prec)
-                )
+                raise InvalidDecimal('A DecimalField with max_digits %d, decimal_places %d must round to an absolute value less than 10^%d.' %
+                                     (model_field.max_digits, model_field.decimal_places, max_prec))
             val = d
         elif isinstance(ogr_field, (OFTReal, OFTString)) and isinstance(model_field, models.IntegerField):
             # Attempt to convert any OFTReal and OFTString value to an OFTInteger.
             try:
                 val = int(ogr_field.value)
-            except ValueError:
+            except:
                 raise InvalidInteger('Could not construct integer from: %s' % ogr_field.value)
         else:
             val = ogr_field.value
@@ -402,7 +374,8 @@ class LayerMapping:
     def verify_fk(self, feat, rel_model, rel_mapping):
         """
         Given an OGR Feature, the related model and its dictionary mapping,
-        retrieve the related model for the ForeignKey mapping.
+        this routine will retrieve the related model for the ForeignKey
+        mapping.
         """
         # TODO: It is expensive to retrieve a model for every record --
         #  explore if an efficient mechanism exists for caching related
@@ -417,14 +390,11 @@ class LayerMapping:
         try:
             return rel_model.objects.using(self.using).get(**fk_kwargs)
         except ObjectDoesNotExist:
-            raise MissingForeignKey(
-                'No ForeignKey %s model found with keyword arguments: %s' %
-                (rel_model.__name__, fk_kwargs)
-            )
+            raise MissingForeignKey('No ForeignKey %s model found with keyword arguments: %s' % (rel_model.__name__, fk_kwargs))
 
     def verify_geom(self, geom, model_field):
         """
-        Verify the geometry -- construct and return a GeometryCollection
+        Verifies the geometry -- will construct and return a GeometryCollection
         if necessary (for example if the model field is MultiPolygonField while
         the mapped shapefile only contains Polygons).
         """
@@ -443,15 +413,14 @@ class LayerMapping:
         # Transforming the geometry with our Coordinate Transformation object,
         # but only if the class variable `transform` is set w/a CoordTransform
         # object.
-        if self.transform:
-            g.transform(self.transform)
+        if self.transform: g.transform(self.transform)
 
         # Returning the WKT of the geometry.
         return g.wkt
 
-    # #### Other model methods ####
+    #### Other model methods ####
     def coord_transform(self):
-        "Return the coordinate transformation object."
+        "Returns the coordinate transformation object."
         SpatialRefSys = self.spatial_backend.spatial_ref_sys()
         try:
             # Getting the target spatial reference system
@@ -459,17 +428,17 @@ class LayerMapping:
 
             # Creating the CoordTransform object
             return CoordTransform(self.source_srs, target_srs)
-        except Exception as exc:
-            raise LayerMapError(
-                'Could not translate between the data source and model geometry.'
-            ) from exc
+        except Exception as msg:
+            new_msg = 'Could not translate between the data source and model geometry: %s' % msg
+            six.reraise(LayerMapError, LayerMapError(new_msg), sys.exc_info()[2])
 
     def geometry_field(self):
-        "Return the GeometryField instance associated with the geographic column."
-        # Use `get_field()` on the model's options so that we
+        "Returns the GeometryField instance associated with the geographic column."
+        # Use the `get_field_by_name` on the model's options so that we
         # get the correct field instance if there's model inheritance.
         opts = self.model._meta
-        return opts.get_field(self.geom_field)
+        fld, model, direct, m2m = opts.get_field_by_name(self.geom_field)
+        return fld
 
     def make_multi(self, geom_type, model_field):
         """
@@ -482,7 +451,7 @@ class LayerMapping:
     def save(self, verbose=False, fid_range=False, step=False,
              progress=False, silent=False, stream=sys.stdout, strict=False):
         """
-        Save the contents from the OGR DataSource Layer into the database
+        Saves the contents from the OGR DataSource Layer into the database
         according to the mapping dictionary given at initialization.
 
         Keyword Parameters:
@@ -503,7 +472,7 @@ class LayerMapping:
 
          progress:
            When this keyword is set, status information will be printed giving
-           the number of features processed and successfully saved.  By default,
+           the number of features processed and sucessfully saved.  By default,
            progress information will pe printed every 1000 features processed,
            however, this default may be overridden by setting this keyword with an
            integer for the desired interval.
@@ -543,8 +512,7 @@ class LayerMapping:
                     kwargs = self.feature_kwargs(feat)
                 except LayerMapError as msg:
                     # Something borked the validation
-                    if strict:
-                        raise
+                    if strict: raise
                     elif not silent:
                         stream.write('Ignoring Feature ID %s because: %s\n' % (feat.fid, msg))
                 else:
@@ -564,14 +532,9 @@ class LayerMapping:
                             # one from the kwargs WKT, adding in additional
                             # geometries, and update the attribute with the
                             # just-updated geometry WKT.
-                            geom_value = getattr(m, self.geom_field)
-                            if geom_value is None:
-                                geom = OGRGeometry(kwargs[self.geom_field])
-                            else:
-                                geom = geom_value.ogr
-                                new = OGRGeometry(kwargs[self.geom_field])
-                                for g in new:
-                                    geom.add(g)
+                            geom = getattr(m, self.geom_field).ogr
+                            new = OGRGeometry(kwargs[self.geom_field])
+                            for g in new: geom.add(g)
                             setattr(m, self.geom_field, geom.wkt)
                         except ObjectDoesNotExist:
                             # No unique model exists yet, create.
@@ -583,16 +546,14 @@ class LayerMapping:
                         # Attempting to save.
                         m.save(using=self.using)
                         num_saved += 1
-                        if verbose:
-                            stream.write('%s: %s\n' % ('Updated' if is_update else 'Saved', m))
+                        if verbose: stream.write('%s: %s\n' % ('Updated' if is_update else 'Saved', m))
+                    except SystemExit:
+                        raise
                     except Exception as msg:
                         if strict:
                             # Bailing out if the `strict` keyword is set.
                             if not silent:
-                                stream.write(
-                                    'Failed to save the feature (id: %s) into the '
-                                    'model with the keyword arguments:\n' % feat.fid
-                                )
+                                stream.write('Failed to save the feature (id: %s) into the model with the keyword arguments:\n' % feat.fid)
                                 stream.write('%s\n' % kwargs)
                             raise
                         elif not silent:
@@ -621,15 +582,13 @@ class LayerMapping:
             for i, end in enumerate(indices):
                 # Constructing the slice to use for this step; the last slice is
                 # special (e.g, [100:] instead of [90:100]).
-                if i + 1 == n_i:
-                    step_slice = slice(beg, None)
-                else:
-                    step_slice = slice(beg, end)
+                if i+1 == n_i: step_slice = slice(beg, None)
+                else: step_slice = slice(beg, end)
 
                 try:
                     num_feat, num_saved = _save(step_slice, num_feat, num_saved)
                     beg = end
-                except Exception:  # Deliberately catch everything
+                except:
                     stream.write('%s\nFailed to save slice: %s\n' % ('=-' * 20, step_slice))
                     raise
         else:
