@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from optparse import make_option
 
 from django.core.management.base import AppCommand
@@ -16,4 +18,4 @@ class Command(AppCommand):
     output_transaction = True
 
     def handle_app(self, app, **options):
-        return u'\n'.join(sql_custom(app, self.style, connections[options.get('database')])).encode('utf-8')
+        return '\n'.join(sql_custom(app, self.style, connections[options.get('database')]))
