@@ -4,7 +4,7 @@ URL. The canonical way to enable cache middleware is to set
 ``UpdateCacheMiddleware`` as your first piece of middleware, and
 ``FetchFromCacheMiddleware`` as the last::
 
-    MIDDLEWARE = [
+    MIDDLEWARE_CLASSES = [
         'django.middleware.cache.UpdateCacheMiddleware',
         ...
         'django.middleware.cache.FetchFromCacheMiddleware'
@@ -43,33 +43,48 @@ More details about how the caching works:
 
 """
 
+import warnings
+
 from django.conf import settings
-from django.core.cache import DEFAULT_CACHE_ALIAS, caches
-from django.utils.cache import (
-    get_cache_key, get_max_age, has_vary_header, learn_cache_key,
-    patch_response_headers,
-)
-from django.utils.deprecation import MiddlewareMixin
+from django.core.cache import get_cache, DEFAULT_CACHE_ALIAS
+from django.utils.cache import (get_cache_key, get_max_age, has_vary_header,
+    learn_cache_key, patch_response_headers)
 
 
-class UpdateCacheMiddleware(MiddlewareMixin):
+class UpdateCacheMiddleware(object):
     """
     Response-phase cache middleware that updates the cache if the response is
     cacheable.
 
     Must be used as part of the two-part update/fetch cache middleware.
-    UpdateCacheMiddleware must be the first piece of middleware in MIDDLEWARE
-    so that it'll get called last during the response phase.
+    UpdateCacheMiddleware must be the first piece of middleware in
+    MIDDLEWARE_CLASSES so that it'll get called last during the response phase.
     """
-    def __init__(self, get_response=None):
+    def __init__(self):
         self.cache_timeout = settings.CACHE_MIDDLEWARE_SECONDS
         self.key_prefix = settings.CACHE_MIDDLEWARE_KEY_PREFIX
+        self.cache_anonymous_only = getattr(settings, 'CACHE_MIDDLEWARE_ANONYMOUS_ONLY', False)
         self.cache_alias = settings.CACHE_MIDDLEWARE_ALIAS
-        self.cache = caches[self.cache_alias]
-        self.get_response = get_response
+        self.cache = get_cache(self.cache_alias)
+
+    def _session_accessed(self, request):
+        try:
+            return request.session.accessed
+        except AttributeError:
+            return False
 
     def _should_update_cache(self, request, response):
-        return hasattr(request, '_cache_update_cache') and request._cache_update_cache
+        if not hasattr(request, '_cache_update_cache') or not request._cache_update_cache:
+            return False
+        # If the session has not been accessed otherwise, we don't want to
+        # cause it to be accessed here. If it hasn't been accessed, then the
+        # user's logged-in status has not affected the response anyway.
+        if self.cache_anonymous_only and self._session_accessed(request):
+            assert hasattr(request, 'user'), "The Django cache middleware with CACHE_MIDDLEWARE_ANONYMOUS_ONLY=True requires authentication middleware to be installed. Edit your MIDDLEWARE_CLASSES setting to insert 'django.contrib.auth.middleware.AuthenticationMiddleware' before the CacheMiddleware."
+            if request.user.is_authenticated():
+                # Don't cache user-variable requests from authenticated users.
+                return False
+        return True
 
     def process_response(self, request, response):
         """Sets the cache, if needed."""
@@ -77,7 +92,7 @@ class UpdateCacheMiddleware(MiddlewareMixin):
             # We don't need to update the cache, just return.
             return response
 
-        if response.streaming or response.status_code not in (200, 304):
+        if response.streaming or response.status_code != 200:
             return response
 
         # Don't cache responses that set a user-specific (and maybe security
@@ -89,13 +104,13 @@ class UpdateCacheMiddleware(MiddlewareMixin):
         # Control" header before reverting to using the default cache_timeout
         # length.
         timeout = get_max_age(response)
-        if timeout is None:
+        if timeout == None:
             timeout = self.cache_timeout
         elif timeout == 0:
             # max-age was set to 0, don't bother caching.
             return response
         patch_response_headers(response, timeout)
-        if timeout and response.status_code == 200:
+        if timeout:
             cache_key = learn_cache_key(request, response, timeout, self.key_prefix, cache=self.cache)
             if hasattr(response, 'render') and callable(response.render):
                 response.add_post_render_callback(
@@ -105,50 +120,48 @@ class UpdateCacheMiddleware(MiddlewareMixin):
                 self.cache.set(cache_key, response, timeout)
         return response
 
-
-class FetchFromCacheMiddleware(MiddlewareMixin):
+class FetchFromCacheMiddleware(object):
     """
     Request-phase cache middleware that fetches a page from the cache.
 
     Must be used as part of the two-part update/fetch cache middleware.
-    FetchFromCacheMiddleware must be the last piece of middleware in MIDDLEWARE
-    so that it'll get called last during the request phase.
+    FetchFromCacheMiddleware must be the last piece of middleware in
+    MIDDLEWARE_CLASSES so that it'll get called last during the request phase.
     """
-    def __init__(self, get_response=None):
+    def __init__(self):
+        self.cache_timeout = settings.CACHE_MIDDLEWARE_SECONDS
         self.key_prefix = settings.CACHE_MIDDLEWARE_KEY_PREFIX
         self.cache_alias = settings.CACHE_MIDDLEWARE_ALIAS
-        self.cache = caches[self.cache_alias]
-        self.get_response = get_response
+        self.cache = get_cache(self.cache_alias)
 
     def process_request(self, request):
         """
         Checks whether the page is already cached and returns the cached
         version if available.
         """
-        if request.method not in ('GET', 'HEAD'):
+        if not request.method in ('GET', 'HEAD'):
             request._cache_update_cache = False
-            return None  # Don't bother checking the cache.
+            return None # Don't bother checking the cache.
 
         # try and get the cached GET response
         cache_key = get_cache_key(request, self.key_prefix, 'GET', cache=self.cache)
         if cache_key is None:
             request._cache_update_cache = True
-            return None  # No cache information available, need to rebuild.
-        response = self.cache.get(cache_key)
+            return None # No cache information available, need to rebuild.
+        response = self.cache.get(cache_key, None)
         # if it wasn't found and we are looking for a HEAD, try looking just for that
         if response is None and request.method == 'HEAD':
             cache_key = get_cache_key(request, self.key_prefix, 'HEAD', cache=self.cache)
-            response = self.cache.get(cache_key)
+            response = self.cache.get(cache_key, None)
 
         if response is None:
             request._cache_update_cache = True
-            return None  # No cache information available, need to rebuild.
+            return None # No cache information available, need to rebuild.
 
         # hit, return cached response
         request._cache_update_cache = False
         return response
 
-
 class CacheMiddleware(UpdateCacheMiddleware, FetchFromCacheMiddleware):
     """
     Cache middleware that provides basic behavior for many simple sites.
@@ -156,30 +169,45 @@ class CacheMiddleware(UpdateCacheMiddleware, FetchFromCacheMiddleware):
     Also used as the hook point for the cache decorator, which is generated
     using the decorator-from-middleware utility.
     """
-    def __init__(self, get_response=None, cache_timeout=None, **kwargs):
-        self.get_response = get_response
+    def __init__(self, cache_timeout=None, cache_anonymous_only=None, **kwargs):
         # We need to differentiate between "provided, but using default value",
         # and "not provided". If the value is provided using a default, then
         # we fall back to system defaults. If it is not provided at all,
         # we need to use middleware defaults.
 
-        try:
-            key_prefix = kwargs['key_prefix']
-            if key_prefix is None:
-                key_prefix = ''
-        except KeyError:
-            key_prefix = settings.CACHE_MIDDLEWARE_KEY_PREFIX
-        self.key_prefix = key_prefix
+        cache_kwargs = {}
 
         try:
-            cache_alias = kwargs['cache_alias']
-            if cache_alias is None:
-                cache_alias = DEFAULT_CACHE_ALIAS
+            self.key_prefix = kwargs['key_prefix']
+            if self.key_prefix is not None:
+                cache_kwargs['KEY_PREFIX'] = self.key_prefix
+            else:
+                self.key_prefix = ''
         except KeyError:
-            cache_alias = settings.CACHE_MIDDLEWARE_ALIAS
-        self.cache_alias = cache_alias
+            self.key_prefix = settings.CACHE_MIDDLEWARE_KEY_PREFIX
+            cache_kwargs['KEY_PREFIX'] = self.key_prefix
 
-        if cache_timeout is None:
-            cache_timeout = settings.CACHE_MIDDLEWARE_SECONDS
-        self.cache_timeout = cache_timeout
-        self.cache = caches[self.cache_alias]
+        try:
+            self.cache_alias = kwargs['cache_alias']
+            if self.cache_alias is None:
+                self.cache_alias = DEFAULT_CACHE_ALIAS
+            if cache_timeout is not None:
+                cache_kwargs['TIMEOUT'] = cache_timeout
+        except KeyError:
+            self.cache_alias = settings.CACHE_MIDDLEWARE_ALIAS
+            if cache_timeout is None:
+                cache_kwargs['TIMEOUT'] = settings.CACHE_MIDDLEWARE_SECONDS
+            else:
+                cache_kwargs['TIMEOUT'] = cache_timeout
+
+        if cache_anonymous_only is None:
+            self.cache_anonymous_only = getattr(settings, 'CACHE_MIDDLEWARE_ANONYMOUS_ONLY', False)
+        else:
+            self.cache_anonymous_only = cache_anonymous_only
+
+        if self.cache_anonymous_only:
+            msg = "CACHE_MIDDLEWARE_ANONYMOUS_ONLY has been deprecated and will be removed in Django 1.8."
+            warnings.warn(msg, PendingDeprecationWarning, stacklevel=1)
+
+        self.cache = get_cache(self.cache_alias, **cache_kwargs)
+        self.cache_timeout = self.cache.default_timeout
