@@ -628,21 +628,7 @@ _add_doc(reraise, """Reraise an exception.""")
 
 def with_metaclass(meta, *bases):
     """Create a base class with a metaclass."""
-    # This requires a bit of explanation: the basic idea is to make a
-    # dummy metaclass for one level of class instantiation that replaces
-    # itself with the actual metaclass.  Because of internal type checks
-    # we also need to make sure that we downgrade the custom metaclass
-    # for one level to something closer to type (that's why __call__ and
-    # __init__ comes back from type etc.).
-    class metaclass(meta):
-        __call__ = type.__call__
-        __init__ = type.__init__
-        def __new__(cls, name, this_bases, d):
-            if this_bases is None:
-                return type.__new__(cls, name, (), d)
-            return meta(name, bases, d)
-    return metaclass('temporary_class', None, {})
-
+    return meta("NewBase", bases, {})
 
 def add_metaclass(metaclass):
     """Class decorator for creating a class with a metaclass."""
@@ -666,18 +652,16 @@ if PY3:
     _assertRaisesRegex = "assertRaisesRegex"
     _assertRegex = "assertRegex"
     memoryview = memoryview
-    buffer_types = (bytes, bytearray, memoryview)
 else:
     _assertRaisesRegex = "assertRaisesRegexp"
     _assertRegex = "assertRegexpMatches"
-    # memoryview and buffer are not strictly equivalent, but should be fine for
+    # memoryview and buffer are not stricly equivalent, but should be fine for
     # django core usage (mainly BinaryField). However, Jython doesn't support
     # buffer (see http://bugs.jython.org/issue1521), so we have to be careful.
     if sys.platform.startswith('java'):
         memoryview = memoryview
     else:
         memoryview = buffer
-    buffer_types = (bytearray, memoryview)
 
 
 def assertRaisesRegex(self, *args, **kwargs):
