@@ -1,23 +1,24 @@
-import uuid
+from __future__ import unicode_literals
 
-from django.contrib.auth.models import User
 from django.db import models
+from django.contrib.auth.models import User
+from django.utils.encoding import python_2_unicode_compatible
 
 
 class MyFileField(models.FileField):
     pass
 
-
+@python_2_unicode_compatible
 class Member(models.Model):
     name = models.CharField(max_length=100)
     birthdate = models.DateTimeField(blank=True, null=True)
-    gender = models.CharField(max_length=1, blank=True, choices=[('M', 'Male'), ('F', 'Female')])
+    gender = models.CharField(max_length=1, blank=True, choices=[('M','Male'), ('F', 'Female')])
     email = models.EmailField(blank=True)
 
     def __str__(self):
         return self.name
 
-
+@python_2_unicode_compatible
 class Band(models.Model):
     name = models.CharField(max_length=100)
     style = models.CharField(max_length=20)
@@ -26,18 +27,9 @@ class Band(models.Model):
     def __str__(self):
         return self.name
 
-
-class UnsafeLimitChoicesTo(models.Model):
-    band = models.ForeignKey(
-        Band,
-        models.CASCADE,
-        limit_choices_to={'name': '"&><escapeme'},
-    )
-
-
+@python_2_unicode_compatible
 class Album(models.Model):
-    band = models.ForeignKey(Band, models.CASCADE)
-    featuring = models.ManyToManyField(Band, related_name='featured')
+    band = models.ForeignKey(Band)
     name = models.CharField(max_length=100)
     cover_art = models.FileField(upload_to='albums')
     backside_art = MyFileField(upload_to='albums_back', null=True)
@@ -45,75 +37,57 @@ class Album(models.Model):
     def __str__(self):
         return self.name
 
-
 class HiddenInventoryManager(models.Manager):
     def get_queryset(self):
-        return super().get_queryset().filter(hidden=False)
-
+        return super(HiddenInventoryManager, self).get_queryset().filter(hidden=False)
 
+@python_2_unicode_compatible
 class Inventory(models.Model):
-    barcode = models.PositiveIntegerField(unique=True)
-    parent = models.ForeignKey('self', models.SET_NULL, to_field='barcode', blank=True, null=True)
-    name = models.CharField(blank=False, max_length=20)
-    hidden = models.BooleanField(default=False)
+   barcode = models.PositiveIntegerField(unique=True)
+   parent = models.ForeignKey('self', to_field='barcode', blank=True, null=True)
+   name = models.CharField(blank=False, max_length=20)
+   hidden = models.BooleanField(default=False)
 
-    # see #9258
-    default_manager = models.Manager()
-    objects = HiddenInventoryManager()
-
-    def __str__(self):
-        return self.name
+   # see #9258
+   default_manager = models.Manager()
+   objects = HiddenInventoryManager()
 
+   def __str__(self):
+      return self.name
 
 class Event(models.Model):
-    main_band = models.ForeignKey(
-        Band,
-        models.CASCADE,
-        limit_choices_to=models.Q(pk__gt=0),
-        related_name='events_main_band_at',
-    )
-    supporting_bands = models.ManyToManyField(
-        Band,
-        blank=True,
-        related_name='events_supporting_band_at',
-        help_text='Supporting Bands.',
-    )
+    band = models.ForeignKey(Band, limit_choices_to=models.Q(pk__gt=0))
     start_date = models.DateField(blank=True, null=True)
     start_time = models.TimeField(blank=True, null=True)
     description = models.TextField(blank=True)
     link = models.URLField(blank=True)
     min_age = models.IntegerField(blank=True, null=True)
 
-
+@python_2_unicode_compatible
 class Car(models.Model):
-    owner = models.ForeignKey(User, models.CASCADE)
+    owner = models.ForeignKey(User)
     make = models.CharField(max_length=30)
     model = models.CharField(max_length=30)
 
     def __str__(self):
         return "%s %s" % (self.make, self.model)
 
-
 class CarTire(models.Model):
     """
     A single car tire. This to test that a user can only select their own cars.
     """
-    car = models.ForeignKey(Car, models.CASCADE)
-
+    car = models.ForeignKey(Car)
 
 class Honeycomb(models.Model):
-    id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
     location = models.CharField(max_length=20)
 
-
 class Bee(models.Model):
     """
     A model with a FK to a model that won't be registered with the admin
     (Honeycomb) so the corresponding raw ID widget won't have a magnifying
     glass link to select related honeycomb instances.
     """
-    honeycomb = models.ForeignKey(Honeycomb, models.CASCADE)
-
+    honeycomb = models.ForeignKey(Honeycomb)
 
 class Individual(models.Model):
     """
@@ -122,14 +96,11 @@ class Individual(models.Model):
     related instances (rendering will be called programmatically in this case).
     """
     name = models.CharField(max_length=20)
-    parent = models.ForeignKey('self', models.SET_NULL, null=True)
-    soulmate = models.ForeignKey('self', models.CASCADE, null=True, related_name='soulmates')
-
+    parent = models.ForeignKey('self', null=True)
 
 class Company(models.Model):
     name = models.CharField(max_length=20)
 
-
 class Advisor(models.Model):
     """
     A model with a m2m to a model that won't be registered with the admin
@@ -140,16 +111,17 @@ class Advisor(models.Model):
     companies = models.ManyToManyField(Company)
 
 
+@python_2_unicode_compatible
 class Student(models.Model):
     name = models.CharField(max_length=255)
 
-    class Meta:
-        ordering = ('name',)
-
     def __str__(self):
         return self.name
 
+    class Meta:
+        ordering = ('name',)
 
+@python_2_unicode_compatible
 class School(models.Model):
     name = models.CharField(max_length=255)
     students = models.ManyToManyField(Student, related_name='current_schools')
@@ -157,10 +129,3 @@ class School(models.Model):
 
     def __str__(self):
         return self.name
-
-
-class Profile(models.Model):
-    user = models.ForeignKey('auth.User', models.CASCADE, to_field='username')
-
-    def __str__(self):
-        return self.user.username
