@@ -5,7 +5,7 @@ from django.utils import six
 
 
 # The models definitions below used to crash. Generating models dynamically
-# at runtime is a bad idea because it pollutes the app registry. This doesn't
+# at runtime is a bad idea because it pollutes the app cache. This doesn't
 # integrate well with the test suite but at least it prevents regressions.
 
 
@@ -20,6 +20,6 @@ class MyModel(six.with_metaclass(CustomBaseModel, models.Model)):
 # still does not fail to create the model.
 
 if six.PY2:
-    class MyPython2Model(models.Model):
+    class MyModel(models.Model):
         """Model subclass with a custom base using __metaclass__."""
         __metaclass__ = CustomBaseModel
