@@ -1,7 +1,6 @@
 from __future__ import unicode_literals
 
 from django.db import models
-from django.utils import timezone
 from django.utils.encoding import python_2_unicode_compatible
 
 
@@ -9,17 +8,15 @@ from django.utils.encoding import python_2_unicode_compatible
 class Article(models.Model):
     title = models.CharField(max_length=100)
     pub_date = models.DateField()
-    pub_datetime = models.DateTimeField(default=timezone.now())
 
     categories = models.ManyToManyField("Category", related_name="articles")
 
     def __str__(self):
         return self.title
 
-
 @python_2_unicode_compatible
 class Comment(models.Model):
-    article = models.ForeignKey(Article, models.CASCADE, related_name="comments")
+    article = models.ForeignKey(Article, related_name="comments")
     text = models.TextField()
     pub_date = models.DateField()
     approval_date = models.DateField(null=True)
@@ -27,6 +24,5 @@ class Comment(models.Model):
     def __str__(self):
         return 'Comment to %s (%s)' % (self.article.title, self.pub_date)
 
-
 class Category(models.Model):
     name = models.CharField(max_length=255)
