@@ -3,26 +3,14 @@ from __future__ import unicode_literals
 
 import datetime
 import decimal
-import unittest
-import warnings
 
-from django.template.defaultfilters import (
-    add, addslashes, capfirst, center, cut, date, default, default_if_none,
-    dictsort, dictsortreversed, divisibleby, escape, escapejs_filter,
-    filesizeformat, first, fix_ampersands_filter, floatformat, force_escape,
-    get_digit, iriencode, join, length, length_is, linebreaksbr,
-    linebreaks_filter, linenumbers, ljust, lower, make_list,
-    phone2numeric_filter, pluralize, removetags, rjust, slice_filter, slugify,
-    stringformat, striptags, time, timesince_filter, timeuntil_filter, title,
-    truncatechars_html, truncatewords, truncatewords_html, unordered_list,
-    upper, urlencode, urlize, urlizetrunc, wordcount, wordwrap, yesno,
-)
+from django.template.defaultfilters import *
 from django.test import TestCase
+from django.test.utils import TransRealMixin
 from django.utils import six
-from django.utils import translation
-from django.utils.deprecation import RemovedInDjango18Warning
-from django.utils.encoding import python_2_unicode_compatible
+from django.utils import unittest, translation
 from django.utils.safestring import SafeData
+from django.utils.encoding import python_2_unicode_compatible
 
 
 class DefaultFiltersTests(TestCase):
@@ -60,7 +48,7 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(floatformat(0, 7), '0.0000000')
         self.assertEqual(floatformat(0, 10), '0.0000000000')
         self.assertEqual(floatformat(0.000000000000000000015, 20),
-                         '0.00000000000000000002')
+                                     '0.00000000000000000002')
 
         pos_inf = float(1e30000)
         self.assertEqual(floatformat(pos_inf), six.text_type(pos_inf))
@@ -74,7 +62,6 @@ class DefaultFiltersTests(TestCase):
         class FloatWrapper(object):
             def __init__(self, value):
                 self.value = value
-
             def __float__(self):
                 return self.value
 
@@ -93,6 +80,7 @@ class DefaultFiltersTests(TestCase):
         finally:
             decimal_ctx.prec = old_prec
 
+
     def test_floatformat_py2_fail(self):
         self.assertEqual(floatformat(1.00000000000000015, 16), '1.0000000000000002')
 
@@ -102,12 +90,13 @@ class DefaultFiltersTests(TestCase):
     if six.PY2:
         test_floatformat_py2_fail = unittest.expectedFailure(test_floatformat_py2_fail)
 
+
     def test_addslashes(self):
         self.assertEqual(addslashes('"double quotes" and \'single quotes\''),
-                         '\\"double quotes\\" and \\\'single quotes\\\'')
+                          '\\"double quotes\\" and \\\'single quotes\\\'')
 
         self.assertEqual(addslashes(r'\ : backslashes, too'),
-                         '\\\\ : backslashes, too')
+                          '\\\\ : backslashes, too')
 
     def test_capfirst(self):
         self.assertEqual(capfirst('hello world'), 'Hello world')
@@ -126,17 +115,15 @@ class DefaultFiltersTests(TestCase):
             'paragraph separator:\\u2029and line separator:\\u2028')
 
     def test_fix_ampersands(self):
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", RemovedInDjango18Warning)
-            self.assertEqual(fix_ampersands_filter('Jack & Jill & Jeroboam'),
-                             'Jack &amp; Jill &amp; Jeroboam')
+        self.assertEqual(fix_ampersands_filter('Jack & Jill & Jeroboam'),
+                          'Jack &amp; Jill &amp; Jeroboam')
 
     def test_linenumbers(self):
         self.assertEqual(linenumbers('line 1\nline 2'),
-                         '1. line 1\n2. line 2')
+                          '1. line 1\n2. line 2')
         self.assertEqual(linenumbers('\n'.join(['x'] * 10)),
-                         '01. x\n02. x\n03. x\n04. x\n05. x\n06. x\n07. '
-                         'x\n08. x\n09. x\n10. x')
+                          '01. x\n02. x\n03. x\n04. x\n05. x\n06. x\n07. '\
+                          'x\n08. x\n09. x\n10. x')
 
     def test_lower(self):
         self.assertEqual(lower('TEST'), 'test')
@@ -149,12 +136,12 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(make_list(1234), ['1', '2', '3', '4'])
 
     def test_slugify(self):
-        self.assertEqual(slugify(' Jack & Jill like numbers 1,2,3 and 4 and'
+        self.assertEqual(slugify(' Jack & Jill like numbers 1,2,3 and 4 and'\
             ' silly characters ?%.$!/'),
             'jack-jill-like-numbers-123-and-4-and-silly-characters')
 
         self.assertEqual(slugify("Un \xe9l\xe9phant \xe0 l'or\xe9e du bois"),
-                         'un-elephant-a-loree-du-bois')
+                          'un-elephant-a-loree-du-bois')
 
     def test_stringformat(self):
         self.assertEqual(stringformat(1, '03d'), '001')
@@ -162,7 +149,7 @@ class DefaultFiltersTests(TestCase):
 
     def test_title(self):
         self.assertEqual(title('a nice title, isn\'t it?'),
-                         "A Nice Title, Isn't It?")
+                          "A Nice Title, Isn't It?")
         self.assertEqual(title('discoth\xe8que'), 'Discoth\xe8que')
 
     def test_truncatewords(self):
@@ -181,7 +168,7 @@ class DefaultFiltersTests(TestCase):
     def test_truncatewords_html(self):
         self.assertEqual(truncatewords_html(
             '<p>one <a href="#">two - three <br>four</a> five</p>', 0), '')
-        self.assertEqual(truncatewords_html('<p>one <a href="#">two - '
+        self.assertEqual(truncatewords_html('<p>one <a href="#">two - '\
             'three <br>four</a> five</p>', 2),
             '<p>one <a href="#">two ...</a></p>')
         self.assertEqual(truncatewords_html(
@@ -195,26 +182,6 @@ class DefaultFiltersTests(TestCase):
             '<p>one <a href="#">two - three <br>four</a> five</p>')
         self.assertEqual(truncatewords_html(
             '\xc5ngstr\xf6m was here', 1), '\xc5ngstr\xf6m ...')
-        self.assertEqual(truncatewords_html('<i>Buenos d&iacute;as! '
-            '&#x00bf;C&oacute;mo est&aacute;?</i>', 3),
-            '<i>Buenos d&iacute;as! &#x00bf;C&oacute;mo ...</i>')
-
-    def test_truncatechars_html(self):
-        self.assertEqual(truncatechars_html(
-            '<p>one <a href="#">two - three <br>four</a> five</p>', 0), '...')
-        self.assertEqual(truncatechars_html('<p>one <a href="#">two - '
-            'three <br>four</a> five</p>', 6),
-            '<p>one...</p>')
-        self.assertEqual(truncatechars_html(
-            '<p>one <a href="#">two - three <br>four</a> five</p>', 11),
-            '<p>one <a href="#">two ...</a></p>')
-        self.assertEqual(truncatechars_html(
-            '<p>one <a href="#">two - three <br>four</a> five</p>', 100),
-            '<p>one <a href="#">two - three <br>four</a> five</p>')
-        self.assertEqual(truncatechars_html(
-            '<b>\xc5ngstr\xf6m</b> was here', 5), '<b>\xc5n...</b>')
-        self.assertEqual(truncatechars_html(
-            'a<b>b</b>c', 3), 'a<b>b</b>c')
 
     def test_upper(self):
         self.assertEqual(upper('Mixed case input'), 'MIXED CASE INPUT')
@@ -223,27 +190,27 @@ class DefaultFiltersTests(TestCase):
 
     def test_urlencode(self):
         self.assertEqual(urlencode('fran\xe7ois & jill'),
-                         'fran%C3%A7ois%20%26%20jill')
+                          'fran%C3%A7ois%20%26%20jill')
         self.assertEqual(urlencode(1), '1')
 
     def test_iriencode(self):
         self.assertEqual(iriencode('S\xf8r-Tr\xf8ndelag'),
-                         'S%C3%B8r-Tr%C3%B8ndelag')
+                          'S%C3%B8r-Tr%C3%B8ndelag')
         self.assertEqual(iriencode(urlencode('fran\xe7ois & jill')),
-                         'fran%C3%A7ois%20%26%20jill')
+                          'fran%C3%A7ois%20%26%20jill')
 
     def test_urlizetrunc(self):
-        self.assertEqual(urlizetrunc('http://short.com/', 20), '<a href='
+        self.assertEqual(urlizetrunc('http://short.com/', 20), '<a href='\
             '"http://short.com/" rel="nofollow">http://short.com/</a>')
 
-        self.assertEqual(urlizetrunc('http://www.google.co.uk/search?hl=en'
-            '&q=some+long+url&btnG=Search&meta=', 20), '<a href="http://'
-            'www.google.co.uk/search?hl=en&q=some+long+url&btnG=Search&'
+        self.assertEqual(urlizetrunc('http://www.google.co.uk/search?hl=en'\
+            '&q=some+long+url&btnG=Search&meta=', 20), '<a href="http://'\
+            'www.google.co.uk/search?hl=en&q=some+long+url&btnG=Search&'\
             'meta=" rel="nofollow">http://www.google...</a>')
 
-        self.assertEqual(urlizetrunc('http://www.google.co.uk/search?hl=en'
-            '&q=some+long+url&btnG=Search&meta=', 20), '<a href="http://'
-            'www.google.co.uk/search?hl=en&q=some+long+url&btnG=Search'
+        self.assertEqual(urlizetrunc('http://www.google.co.uk/search?hl=en'\
+            '&q=some+long+url&btnG=Search&meta=', 20), '<a href="http://'\
+            'www.google.co.uk/search?hl=en&q=some+long+url&btnG=Search'\
             '&meta=" rel="nofollow">http://www.google...</a>')
 
         # Check truncating of URIs which are the exact length
@@ -251,15 +218,15 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(len(uri), 31)
 
         self.assertEqual(urlizetrunc(uri, 31),
-            '<a href="http://31characteruri.com/test/" rel="nofollow">'
+            '<a href="http://31characteruri.com/test/" rel="nofollow">'\
             'http://31characteruri.com/test/</a>')
 
         self.assertEqual(urlizetrunc(uri, 30),
-            '<a href="http://31characteruri.com/test/" rel="nofollow">'
+            '<a href="http://31characteruri.com/test/" rel="nofollow">'\
             'http://31characteruri.com/t...</a>')
 
         self.assertEqual(urlizetrunc(uri, 2),
-            '<a href="http://31characteruri.com/test/"'
+            '<a href="http://31characteruri.com/test/"'\
             ' rel="nofollow">...</a>')
 
     def test_urlize(self):
@@ -343,9 +310,9 @@ class DefaultFiltersTests(TestCase):
 
         # Check urlize handles brackets properly (#19070)
         self.assertEqual(urlize('[see www.example.com]'),
-            '[see <a href="http://www.example.com" rel="nofollow">www.example.com</a>]')
+            '[see <a href="http://www.example.com" rel="nofollow">www.example.com</a>]' )
         self.assertEqual(urlize('see test[at[example.com'),
-            'see <a href="http://test[at[example.com" rel="nofollow">test[at[example.com</a>')
+            'see <a href="http://test[at[example.com" rel="nofollow">test[at[example.com</a>' )
         self.assertEqual(urlize('[http://168.192.0.1](http://168.192.0.1)'),
             '[<a href="http://168.192.0.1](http://168.192.0.1)" rel="nofollow">http://168.192.0.1](http://168.192.0.1)</a>')
 
@@ -355,41 +322,23 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(urlize('http://[2001:db8:cafe::2]/api/9'),
             '<a href="http://[2001:db8:cafe::2]/api/9" rel="nofollow">http://[2001:db8:cafe::2]/api/9</a>')
 
-        # Check urlize correctly include quotation marks in links - #20364
-        self.assertEqual(urlize('before "hi@example.com" afterwards'),
-                         'before "<a href="mailto:hi@example.com">hi@example.com</a>" afterwards')
-        self.assertEqual(urlize('before hi@example.com" afterwards'),
-                         'before <a href="mailto:hi@example.com">hi@example.com</a>" afterwards')
-        self.assertEqual(urlize('before "hi@example.com afterwards'),
-                         'before "<a href="mailto:hi@example.com">hi@example.com</a> afterwards')
-        self.assertEqual(urlize('before \'hi@example.com\' afterwards'),
-                         'before \'<a href="mailto:hi@example.com">hi@example.com</a>\' afterwards')
-        self.assertEqual(urlize('before hi@example.com\' afterwards'),
-                         'before <a href="mailto:hi@example.com">hi@example.com</a>\' afterwards')
-        self.assertEqual(urlize('before \'hi@example.com afterwards'),
-                         'before \'<a href="mailto:hi@example.com">hi@example.com</a> afterwards')
-
-        # Check urlize copes with commas following URLs in quotes - see #20364
-        self.assertEqual(urlize('Email us at "hi@example.com", or phone us at +xx.yy'),
-            'Email us at "<a href="mailto:hi@example.com">hi@example.com</a>", or phone us at +xx.yy')
-
     def test_wordcount(self):
         self.assertEqual(wordcount(''), 0)
         self.assertEqual(wordcount('oneword'), 1)
         self.assertEqual(wordcount('lots of words'), 3)
 
-        self.assertEqual(wordwrap('this is a long paragraph of text that '
+        self.assertEqual(wordwrap('this is a long paragraph of text that '\
             'really needs to be wrapped I\'m afraid', 14),
-            "this is a long\nparagraph of\ntext that\nreally needs\nto be "
+            "this is a long\nparagraph of\ntext that\nreally needs\nto be "\
             "wrapped\nI'm afraid")
 
-        self.assertEqual(wordwrap('this is a short paragraph of text.\n  '
+        self.assertEqual(wordwrap('this is a short paragraph of text.\n  '\
             'But this line should be indented', 14),
-            'this is a\nshort\nparagraph of\ntext.\n  But this\nline '
+            'this is a\nshort\nparagraph of\ntext.\n  But this\nline '\
             'should be\nindented')
 
-        self.assertEqual(wordwrap('this is a short paragraph of text.\n  '
-            'But this line should be indented', 15), 'this is a short\n'
+        self.assertEqual(wordwrap('this is a short paragraph of text.\n  '\
+            'But this line should be indented',15), 'this is a short\n'\
             'paragraph of\ntext.\n  But this line\nshould be\nindented')
 
     def test_rjust(self):
@@ -403,11 +352,11 @@ class DefaultFiltersTests(TestCase):
 
     def test_cut(self):
         self.assertEqual(cut('a string to be mangled', 'a'),
-                         ' string to be mngled')
+                          ' string to be mngled')
         self.assertEqual(cut('a string to be mangled', 'ng'),
-                         'a stri to be maled')
+                          'a stri to be maled')
         self.assertEqual(cut('a string to be mangled', 'strings'),
-                         'a string to be mangled')
+                          'a string to be mangled')
 
     def test_force_escape(self):
         escaped = force_escape('<some html & special characters > here')
@@ -416,31 +365,31 @@ class DefaultFiltersTests(TestCase):
         self.assertIsInstance(escaped, SafeData)
         self.assertEqual(
             force_escape('<some html & special characters > here ĐÅ€£'),
-            '&lt;some html &amp; special characters &gt; here'
+            '&lt;some html &amp; special characters &gt; here'\
             ' \u0110\xc5\u20ac\xa3')
 
     def test_linebreaks(self):
         self.assertEqual(linebreaks_filter('line 1'), '<p>line 1</p>')
         self.assertEqual(linebreaks_filter('line 1\nline 2'),
-                         '<p>line 1<br />line 2</p>')
+                          '<p>line 1<br />line 2</p>')
         self.assertEqual(linebreaks_filter('line 1\rline 2'),
-                         '<p>line 1<br />line 2</p>')
+                          '<p>line 1<br />line 2</p>')
         self.assertEqual(linebreaks_filter('line 1\r\nline 2'),
-                         '<p>line 1<br />line 2</p>')
+                          '<p>line 1<br />line 2</p>')
 
     def test_linebreaksbr(self):
         self.assertEqual(linebreaksbr('line 1\nline 2'),
-                         'line 1<br />line 2')
+                          'line 1<br />line 2')
         self.assertEqual(linebreaksbr('line 1\rline 2'),
-                         'line 1<br />line 2')
+                          'line 1<br />line 2')
         self.assertEqual(linebreaksbr('line 1\r\nline 2'),
-                         'line 1<br />line 2')
+                          'line 1<br />line 2')
 
     def test_removetags(self):
-        self.assertEqual(removetags('some <b>html</b> with <script>alert'
+        self.assertEqual(removetags('some <b>html</b> with <script>alert'\
             '("You smell")</script> disallowed <img /> tags', 'script img'),
             'some <b>html</b> with alert("You smell") disallowed  tags')
-        self.assertEqual(striptags('some <b>html</b> with <script>alert'
+        self.assertEqual(striptags('some <b>html</b> with <script>alert'\
             '("You smell")</script> disallowed <img /> tags'),
             'some html with alert("You smell") disallowed  tags')
 
@@ -461,20 +410,6 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(dictsort({'a': 1}, 'age'), '')
         self.assertEqual(dictsort(1, 'age'), '')
 
-    def test_dictsort_complex_sorting_key(self):
-        """
-        Since dictsort uses template.Variable under the hood, it can sort
-        on keys like 'foo.bar'.
-        """
-        data = [
-            {'foo': {'bar': 1, 'baz': 'c'}},
-            {'foo': {'bar': 2, 'baz': 'b'}},
-            {'foo': {'bar': 3, 'baz': 'a'}},
-        ]
-        sorted_data = dictsort(data, 'foo.baz')
-
-        self.assertEqual([d['foo']['bar'] for d in sorted_data], [3, 2, 1])
-
     def test_dictsortreversed(self):
         sorted_dicts = dictsortreversed([{'age': 23, 'name': 'Barbara-Ann'},
                                          {'age': 63, 'name': 'Ra Ra Rasputin'},
@@ -494,16 +429,16 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(dictsortreversed(1, 'age'), '')
 
     def test_first(self):
-        self.assertEqual(first([0, 1, 2]), 0)
+        self.assertEqual(first([0,1,2]), 0)
         self.assertEqual(first(''), '')
         self.assertEqual(first('test'), 't')
 
     def test_join(self):
-        self.assertEqual(join([0, 1, 2], 'glue'), '0glue1glue2')
+        self.assertEqual(join([0,1,2], 'glue'), '0glue1glue2')
 
     def test_length(self):
         self.assertEqual(length('1234'), 4)
-        self.assertEqual(length([1, 2, 3, 4]), 4)
+        self.assertEqual(length([1,2,3,4]), 4)
         self.assertEqual(length_is([], 0), True)
         self.assertEqual(length_is([], 1), False)
         self.assertEqual(length_is('a', 1), True)
@@ -525,32 +460,33 @@ class DefaultFiltersTests(TestCase):
 
         self.assertEqual(
             unordered_list(['item 1', ['item 1.1', 'item1.2'], 'item 2']),
-            '\t<li>item 1\n\t<ul>\n\t\t<li>item 1.1</li>\n\t\t<li>item1.2'
+            '\t<li>item 1\n\t<ul>\n\t\t<li>item 1.1</li>\n\t\t<li>item1.2'\
             '</li>\n\t</ul>\n\t</li>\n\t<li>item 2</li>')
 
         self.assertEqual(
-            unordered_list(['item 1', ['item 1.1', ['item 1.1.1', ['item 1.1.1.1']]]]),
-            '\t<li>item 1\n\t<ul>\n\t\t<li>item 1.1\n\t\t<ul>\n\t\t\t<li>'
-            'item 1.1.1\n\t\t\t<ul>\n\t\t\t\t<li>item 1.1.1.1</li>\n\t\t\t'
+            unordered_list(['item 1', ['item 1.1', ['item 1.1.1',
+                                                      ['item 1.1.1.1']]]]),
+            '\t<li>item 1\n\t<ul>\n\t\t<li>item 1.1\n\t\t<ul>\n\t\t\t<li>'\
+            'item 1.1.1\n\t\t\t<ul>\n\t\t\t\t<li>item 1.1.1.1</li>\n\t\t\t'\
             '</ul>\n\t\t\t</li>\n\t\t</ul>\n\t\t</li>\n\t</ul>\n\t</li>')
 
         self.assertEqual(unordered_list(
             ['States', ['Kansas', ['Lawrence', 'Topeka'], 'Illinois']]),
-            '\t<li>States\n\t<ul>\n\t\t<li>Kansas\n\t\t<ul>\n\t\t\t<li>'
-            'Lawrence</li>\n\t\t\t<li>Topeka</li>\n\t\t</ul>\n\t\t</li>'
+            '\t<li>States\n\t<ul>\n\t\t<li>Kansas\n\t\t<ul>\n\t\t\t<li>'\
+            'Lawrence</li>\n\t\t\t<li>Topeka</li>\n\t\t</ul>\n\t\t</li>'\
             '\n\t\t<li>Illinois</li>\n\t</ul>\n\t</li>')
 
         @python_2_unicode_compatible
         class ULItem(object):
             def __init__(self, title):
-                self.title = title
-
+              self.title = title
             def __str__(self):
                 return 'ulitem-%s' % str(self.title)
 
         a = ULItem('a')
         b = ULItem('b')
-        self.assertEqual(unordered_list([a, b]), '\t<li>ulitem-a</li>\n\t<li>ulitem-b</li>')
+        self.assertEqual(unordered_list([a,b]),
+                          '\t<li>ulitem-a</li>\n\t<li>ulitem-b</li>')
 
         # Old format for unordered lists should still work
         self.assertEqual(unordered_list(['item 1', []]), '\t<li>item 1</li>')
@@ -559,13 +495,13 @@ class DefaultFiltersTests(TestCase):
             '\t<li>item 1\n\t<ul>\n\t\t<li>item 1.1</li>\n\t</ul>\n\t</li>')
 
         self.assertEqual(unordered_list(['item 1', [['item 1.1', []],
-            ['item 1.2', []]]]), '\t<li>item 1\n\t<ul>\n\t\t<li>item 1.1'
+            ['item 1.2', []]]]), '\t<li>item 1\n\t<ul>\n\t\t<li>item 1.1'\
             '</li>\n\t\t<li>item 1.2</li>\n\t</ul>\n\t</li>')
 
         self.assertEqual(unordered_list(['States', [['Kansas', [['Lawrence',
-            []], ['Topeka', []]]], ['Illinois', []]]]), '\t<li>States\n\t'
-            '<ul>\n\t\t<li>Kansas\n\t\t<ul>\n\t\t\t<li>Lawrence</li>'
-            '\n\t\t\t<li>Topeka</li>\n\t\t</ul>\n\t\t</li>\n\t\t<li>'
+            []], ['Topeka', []]]], ['Illinois', []]]]), '\t<li>States\n\t'\
+            '<ul>\n\t\t<li>Kansas\n\t\t<ul>\n\t\t\t<li>Lawrence</li>'\
+            '\n\t\t\t<li>Topeka</li>\n\t\t</ul>\n\t\t</li>\n\t\t<li>'\
             'Illinois</li>\n\t</ul>\n\t</li>')
 
     def test_add(self):
@@ -582,9 +518,9 @@ class DefaultFiltersTests(TestCase):
     def test_date(self):
         # real testing of date() is in dateformat.py
         self.assertEqual(date(datetime.datetime(2005, 12, 29), "d F Y"),
-                         '29 December 2005')
+                          '29 December 2005')
         self.assertEqual(date(datetime.datetime(2005, 12, 29), r'jS \o\f F'),
-                         '29th of December')
+                          '29th of December')
 
     def test_time(self):
         # real testing of time() is done in dateformat.py
@@ -633,30 +569,32 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(yesno(False), 'no')
         self.assertEqual(yesno(None), 'maybe')
         self.assertEqual(yesno(True, 'certainly,get out of town,perhaps'),
-                         'certainly')
+                          'certainly')
         self.assertEqual(yesno(False, 'certainly,get out of town,perhaps'),
-                         'get out of town')
+                          'get out of town')
         self.assertEqual(yesno(None, 'certainly,get out of town,perhaps'),
-                         'perhaps')
+                          'perhaps')
         self.assertEqual(yesno(None, 'certainly,get out of town'),
-                         'get out of town')
+                          'get out of town')
 
     def test_filesizeformat(self):
         # NOTE: \xa0 avoids wrapping between value and unit
         self.assertEqual(filesizeformat(1023), '1023\xa0bytes')
         self.assertEqual(filesizeformat(1024), '1.0\xa0KB')
-        self.assertEqual(filesizeformat(10 * 1024), '10.0\xa0KB')
-        self.assertEqual(filesizeformat(1024 * 1024 - 1), '1024.0\xa0KB')
-        self.assertEqual(filesizeformat(1024 * 1024), '1.0\xa0MB')
-        self.assertEqual(filesizeformat(1024 * 1024 * 50), '50.0\xa0MB')
-        self.assertEqual(filesizeformat(1024 * 1024 * 1024 - 1), '1024.0\xa0MB')
-        self.assertEqual(filesizeformat(1024 * 1024 * 1024), '1.0\xa0GB')
-        self.assertEqual(filesizeformat(1024 * 1024 * 1024 * 1024), '1.0\xa0TB')
-        self.assertEqual(filesizeformat(1024 * 1024 * 1024 * 1024 * 1024), '1.0\xa0PB')
-        self.assertEqual(filesizeformat(1024 * 1024 * 1024 * 1024 * 1024 * 2000), '2000.0\xa0PB')
-        self.assertEqual(filesizeformat(complex(1, -1)), '0\xa0bytes')
+        self.assertEqual(filesizeformat(10*1024), '10.0\xa0KB')
+        self.assertEqual(filesizeformat(1024*1024-1), '1024.0\xa0KB')
+        self.assertEqual(filesizeformat(1024*1024), '1.0\xa0MB')
+        self.assertEqual(filesizeformat(1024*1024*50), '50.0\xa0MB')
+        self.assertEqual(filesizeformat(1024*1024*1024-1), '1024.0\xa0MB')
+        self.assertEqual(filesizeformat(1024*1024*1024), '1.0\xa0GB')
+        self.assertEqual(filesizeformat(1024*1024*1024*1024), '1.0\xa0TB')
+        self.assertEqual(filesizeformat(1024*1024*1024*1024*1024), '1.0\xa0PB')
+        self.assertEqual(filesizeformat(1024*1024*1024*1024*1024*2000),
+                          '2000.0\xa0PB')
+        self.assertEqual(filesizeformat(complex(1,-1)), '0\xa0bytes')
         self.assertEqual(filesizeformat(""), '0\xa0bytes')
-        self.assertEqual(filesizeformat("\N{GREEK SMALL LETTER ALPHA}"), '0\xa0bytes')
+        self.assertEqual(filesizeformat("\N{GREEK SMALL LETTER ALPHA}"),
+                          '0\xa0bytes')
 
     def test_pluralize(self):
         self.assertEqual(pluralize(1), '')
@@ -664,14 +602,14 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(pluralize(2), 's')
         self.assertEqual(pluralize([1]), '')
         self.assertEqual(pluralize([]), 's')
-        self.assertEqual(pluralize([1, 2, 3]), 's')
-        self.assertEqual(pluralize(1, 'es'), '')
-        self.assertEqual(pluralize(0, 'es'), 'es')
-        self.assertEqual(pluralize(2, 'es'), 'es')
-        self.assertEqual(pluralize(1, 'y,ies'), 'y')
-        self.assertEqual(pluralize(0, 'y,ies'), 'ies')
-        self.assertEqual(pluralize(2, 'y,ies'), 'ies')
-        self.assertEqual(pluralize(0, 'y,ies,error'), '')
+        self.assertEqual(pluralize([1,2,3]), 's')
+        self.assertEqual(pluralize(1,'es'), '')
+        self.assertEqual(pluralize(0,'es'), 'es')
+        self.assertEqual(pluralize(2,'es'), 'es')
+        self.assertEqual(pluralize(1,'y,ies'), 'y')
+        self.assertEqual(pluralize(0,'y,ies'), 'ies')
+        self.assertEqual(pluralize(2,'y,ies'), 'ies')
+        self.assertEqual(pluralize(0,'y,ies,error'), '')
 
     def test_phone2numeric(self):
         self.assertEqual(phone2numeric_filter('0800 flowers'), '0800 3569377')
@@ -703,22 +641,26 @@ class DefaultFiltersTests(TestCase):
         self.assertEqual(striptags(123), '123')
 
 
-class DefaultFiltersI18NTests(TestCase):
+class DefaultFiltersI18NTests(TransRealMixin, TestCase):
 
     def test_localized_filesizeformat(self):
         # NOTE: \xa0 avoids wrapping between value and unit
-        with self.settings(USE_L10N=True), translation.override('de'):
-            self.assertEqual(filesizeformat(1023), '1023\xa0Bytes')
-            self.assertEqual(filesizeformat(1024), '1,0\xa0KB')
-            self.assertEqual(filesizeformat(10 * 1024), '10,0\xa0KB')
-            self.assertEqual(filesizeformat(1024 * 1024 - 1), '1024,0\xa0KB')
-            self.assertEqual(filesizeformat(1024 * 1024), '1,0\xa0MB')
-            self.assertEqual(filesizeformat(1024 * 1024 * 50), '50,0\xa0MB')
-            self.assertEqual(filesizeformat(1024 * 1024 * 1024 - 1), '1024,0\xa0MB')
-            self.assertEqual(filesizeformat(1024 * 1024 * 1024), '1,0\xa0GB')
-            self.assertEqual(filesizeformat(1024 * 1024 * 1024 * 1024), '1,0\xa0TB')
-            self.assertEqual(filesizeformat(1024 * 1024 * 1024 * 1024 * 1024), '1,0\xa0PB')
-            self.assertEqual(filesizeformat(1024 * 1024 * 1024 * 1024 * 1024 * 2000), '2000,0\xa0PB')
-            self.assertEqual(filesizeformat(complex(1, -1)), '0\xa0Bytes')
-            self.assertEqual(filesizeformat(""), '0\xa0Bytes')
-            self.assertEqual(filesizeformat("\N{GREEK SMALL LETTER ALPHA}"), '0\xa0Bytes')
+        with self.settings(USE_L10N=True):
+            with translation.override('de', deactivate=True):
+                self.assertEqual(filesizeformat(1023), '1023\xa0Bytes')
+                self.assertEqual(filesizeformat(1024), '1,0\xa0KB')
+                self.assertEqual(filesizeformat(10*1024), '10,0\xa0KB')
+                self.assertEqual(filesizeformat(1024*1024-1), '1024,0\xa0KB')
+                self.assertEqual(filesizeformat(1024*1024), '1,0\xa0MB')
+                self.assertEqual(filesizeformat(1024*1024*50), '50,0\xa0MB')
+                self.assertEqual(filesizeformat(1024*1024*1024-1), '1024,0\xa0MB')
+                self.assertEqual(filesizeformat(1024*1024*1024), '1,0\xa0GB')
+                self.assertEqual(filesizeformat(1024*1024*1024*1024), '1,0\xa0TB')
+                self.assertEqual(filesizeformat(1024*1024*1024*1024*1024),
+                                  '1,0\xa0PB')
+                self.assertEqual(filesizeformat(1024*1024*1024*1024*1024*2000),
+                                  '2000,0\xa0PB')
+                self.assertEqual(filesizeformat(complex(1,-1)), '0\xa0Bytes')
+                self.assertEqual(filesizeformat(""), '0\xa0Bytes')
+                self.assertEqual(filesizeformat("\N{GREEK SMALL LETTER ALPHA}"),
+                                  '0\xa0Bytes')
