@@ -1,59 +1,67 @@
+from __future__ import absolute_import
+
 import datetime
 
-from django.db import connection, models, transaction
-from django.db.models import Exists, OuterRef
-from django.test import (
-    SimpleTestCase, TestCase, TransactionTestCase, skipUnlessDBFeature,
-)
+from django.conf import settings
+from django.db import transaction, DEFAULT_DB_ALIAS, models
+from django.db.utils import ConnectionHandler
+from django.test import TestCase, TransactionTestCase, skipUnlessDBFeature
 
-from .models import (
-    Award, AwardNote, Book, Child, Contact, Eaten, Email, File, Food, FooFile,
-    FooFileProxy, FooImage, FooPhoto, House, Image, Item, Location, Login,
-    OrderedPerson, OrgUnit, Person, Photo, PlayedWith, PlayedWithNote, Policy,
-    Researcher, Toy, Version,
-)
+from .models import (Book, Award, AwardNote, Person, Child, Toy, PlayedWith,
+    PlayedWithNote, Email, Researcher, Food, Eaten, Policy, Version, Location,
+    Item, Image, File, Photo, FooFile, FooImage, FooPhoto, FooFileProxy, Login,
+    OrgUnit, OrderedPerson, House)
 
 
 # Can't run this test under SQLite, because you can't
 # get two connections to an in-memory database.
-@skipUnlessDBFeature('test_db_allows_multiple_connections')
 class DeleteLockingTest(TransactionTestCase):
 
     available_apps = ['delete_regress']
 
     def setUp(self):
         # Create a second connection to the default database
-        self.conn2 = connection.copy()
-        self.conn2.set_autocommit(False)
+        new_connections = ConnectionHandler(settings.DATABASES)
+        self.conn2 = new_connections[DEFAULT_DB_ALIAS]
+        # Put both DB connections into managed transaction mode
+        transaction.enter_transaction_management()
+        self.conn2.enter_transaction_management()
 
     def tearDown(self):
         # Close down the second connection.
-        self.conn2.rollback()
+        transaction.leave_transaction_management()
+        self.conn2.abort()
         self.conn2.close()
 
+    @skipUnlessDBFeature('test_db_allows_multiple_connections')
     def test_concurrent_delete(self):
-        """Concurrent deletes don't collide and lock the database (#9479)."""
-        with transaction.atomic():
-            Book.objects.create(id=1, pagecount=100)
-            Book.objects.create(id=2, pagecount=200)
-            Book.objects.create(id=3, pagecount=300)
+        "Deletes on concurrent transactions don't collide and lock the database. Regression for #9479"
 
-        with transaction.atomic():
-            # Start a transaction on the main connection.
-            self.assertEqual(3, Book.objects.count())
+        # Create some dummy data
+        b1 = Book(id=1, pagecount=100)
+        b2 = Book(id=2, pagecount=200)
+        b3 = Book(id=3, pagecount=300)
+        b1.save()
+        b2.save()
+        b3.save()
 
-            # Delete something using another database connection.
-            with self.conn2.cursor() as cursor2:
-                cursor2.execute("DELETE from delete_regress_book WHERE id = 1")
-            self.conn2.commit()
+        transaction.commit()
 
-            # In the same transaction on the main connection, perform a
-            # queryset delete that covers the object deleted with the other
-            # connection. This causes an infinite loop under MySQL InnoDB
-            # unless we keep track of already deleted objects.
-            Book.objects.filter(pagecount__lt=250).delete()
+        self.assertEqual(3, Book.objects.count())
 
+        # Delete something using connection 2.
+        cursor2 = self.conn2.cursor()
+        cursor2.execute('DELETE from delete_regress_book WHERE id=1')
+        self.conn2._commit()
+
+        # Now perform a queryset delete that covers the object
+        # deleted in connection 2. This causes an infinite loop
+        # under MySQL InnoDB unless we keep track of already
+        # deleted objects.
+        Book.objects.filter(pagecount__lt=250).delete()
+        transaction.commit()
         self.assertEqual(1, Book.objects.count())
+        transaction.commit()
 
 
 class DeleteCascadeTests(TestCase):
@@ -61,10 +69,12 @@ class DeleteCascadeTests(TestCase):
         """
         Django cascades deletes through generic-related objects to their
         reverse relations.
+
         """
         person = Person.objects.create(name='Nelson Mandela')
         award = Award.objects.create(name='Nobel', content_object=person)
-        AwardNote.objects.create(note='a peace prize', award=award)
+        note = AwardNote.objects.create(note='a peace prize',
+                                        award=award)
         self.assertEqual(AwardNote.objects.count(), 1)
         person.delete()
         self.assertEqual(Award.objects.count(), 0)
@@ -77,11 +87,14 @@ class DeleteCascadeTests(TestCase):
         some other model has an FK to that through model, deletion is cascaded
         from one of the participants in the M2M, to the through model, to its
         related model.
+
         """
         juan = Child.objects.create(name='Juan')
         paints = Toy.objects.create(name='Paints')
-        played = PlayedWith.objects.create(child=juan, toy=paints, date=datetime.date.today())
-        PlayedWithNote.objects.create(played=played, note='the next Jackson Pollock')
+        played = PlayedWith.objects.create(child=juan, toy=paints,
+                                           date=datetime.date.today())
+        note = PlayedWithNote.objects.create(played=played,
+                                             note='the next Jackson Pollock')
         self.assertEqual(PlayedWithNote.objects.count(), 1)
         paints.delete()
         self.assertEqual(PlayedWith.objects.count(), 0)
@@ -92,7 +105,7 @@ class DeleteCascadeTests(TestCase):
         policy = Policy.objects.create(pk=1, policy_number="1234")
         version = Version.objects.create(policy=policy)
         location = Location.objects.create(version=version)
-        Item.objects.create(version=version, location=location)
+        item = Item.objects.create(version=version, location=location)
         policy.delete()
 
 
@@ -119,9 +132,10 @@ class DeleteCascadeTransactionTests(TransactionTestCase):
     def test_to_field(self):
         """
         Cascade deletion works with ForeignKey.to_field set to non-PK.
+
         """
         apple = Food.objects.create(name="apple")
-        Eaten.objects.create(food=apple, meal="lunch")
+        eaten = Eaten.objects.create(food=apple, meal="lunch")
 
         apple.delete()
         self.assertFalse(Food.objects.exists())
@@ -132,9 +146,8 @@ class LargeDeleteTests(TestCase):
     def test_large_deletes(self):
         "Regression for #13309 -- if the number of objects > chunk size, deletion still occurs"
         for x in range(300):
-            Book.objects.create(pagecount=x + 100)
+            track = Book.objects.create(pagecount=x+100)
         # attach a signal to make sure we will not fast-delete
-
         def noop(*args, **kwargs):
             pass
         models.signals.post_delete.connect(noop, sender=Book)
@@ -148,6 +161,7 @@ class ProxyDeleteTest(TestCase):
     Tests on_delete behavior for proxy models.
 
     See #16128.
+
     """
     def create_image(self):
         """Return an Image referenced by both a FooImage and a FooFile."""
@@ -164,10 +178,12 @@ class ProxyDeleteTest(TestCase):
 
         return test_image
 
+
     def test_delete_proxy(self):
         """
         Deleting the *proxy* instance bubbles through to its non-proxy and
         *all* referring objects are deleted.
+
         """
         self.create_image()
 
@@ -181,10 +197,12 @@ class ProxyDeleteTest(TestCase):
         self.assertEqual(len(FooImage.objects.all()), 0)
         self.assertEqual(len(FooFile.objects.all()), 0)
 
+
     def test_delete_proxy_of_proxy(self):
         """
         Deleting a proxy-of-proxy instance should bubble through to its proxy
         and non-proxy parents, deleting *all* referring objects.
+
         """
         test_image = self.create_image()
 
@@ -206,10 +224,12 @@ class ProxyDeleteTest(TestCase):
         self.assertEqual(len(FooFile.objects.all()), 0)
         self.assertEqual(len(FooImage.objects.all()), 0)
 
+
     def test_delete_concrete_parent(self):
         """
         Deleting an instance of a concrete model should also delete objects
         referencing its proxy subclass.
+
         """
         self.create_image()
 
@@ -224,6 +244,7 @@ class ProxyDeleteTest(TestCase):
         self.assertEqual(len(FooFile.objects.all()), 0)
         self.assertEqual(len(FooImage.objects.all()), 0)
 
+
     def test_delete_proxy_pair(self):
         """
         If a pair of proxy models are linked by an FK from one concrete parent
@@ -232,6 +253,7 @@ class ProxyDeleteTest(TestCase):
         IntegrityError on databases unable to defer integrity checks).
 
         Refs #17918.
+
         """
         # Create an Image (proxy of File) and FooFileProxy (proxy of FooFile,
         # which has an FK to File)
@@ -244,13 +266,11 @@ class ProxyDeleteTest(TestCase):
         self.assertEqual(len(FooFileProxy.objects.all()), 0)
 
     def test_19187_values(self):
-        msg = 'Cannot call delete() after .values() or .values_list()'
-        with self.assertRaisesMessage(TypeError, msg):
+        with self.assertRaises(TypeError):
             Image.objects.values().delete()
-        with self.assertRaisesMessage(TypeError, msg):
+        with self.assertRaises(TypeError):
             Image.objects.values_list().delete()
 
-
 class Ticket19102Tests(TestCase):
     """
     Test different queries which alter the SELECT clause of the query. We
@@ -261,12 +281,11 @@ class Ticket19102Tests(TestCase):
     Note that .values() is not tested here on purpose. .values().delete()
     doesn't work for non fast-path deletes at all.
     """
-    @classmethod
-    def setUpTestData(cls):
-        cls.o1 = OrgUnit.objects.create(name='o1')
-        cls.o2 = OrgUnit.objects.create(name='o2')
-        cls.l1 = Login.objects.create(description='l1', orgunit=cls.o1)
-        cls.l2 = Login.objects.create(description='l2', orgunit=cls.o2)
+    def setUp(self):
+        self.o1 = OrgUnit.objects.create(name='o1')
+        self.o2 = OrgUnit.objects.create(name='o2')
+        self.l1 = Login.objects.create(description='l1', orgunit=self.o1)
+        self.l2 = Login.objects.create(description='l2', orgunit=self.o2)
 
     @skipUnlessDBFeature("update_can_self_select")
     def test_ticket_19102_annotate(self):
@@ -287,13 +306,27 @@ class Ticket19102Tests(TestCase):
             Login.objects.order_by('description').filter(
                 orgunit__name__isnull=False
             ).extra(
-                select={'extraf': '1'}
+                select={'extraf':'1'}
             ).filter(
                 pk=self.l1.pk
             ).delete()
         self.assertFalse(Login.objects.filter(pk=self.l1.pk).exists())
         self.assertTrue(Login.objects.filter(pk=self.l2.pk).exists())
 
+    @skipUnlessDBFeature("update_can_self_select")
+    @skipUnlessDBFeature('can_distinct_on_fields')
+    def test_ticket_19102_distinct_on(self):
+        # Both Login objs should have same description so that only the one
+        # having smaller PK will be deleted.
+        Login.objects.update(description='description')
+        with self.assertNumQueries(1):
+            Login.objects.distinct('description').order_by('pk').filter(
+                orgunit__name__isnull=False
+            ).delete()
+        # Assumed that l1 which is created first has smaller PK.
+        self.assertFalse(Login.objects.filter(pk=self.l1.pk).exists())
+        self.assertTrue(Login.objects.filter(pk=self.l2.pk).exists())
+
     @skipUnlessDBFeature("update_can_self_select")
     def test_ticket_19102_select_related(self):
         with self.assertNumQueries(1):
@@ -321,7 +354,7 @@ class Ticket19102Tests(TestCase):
         self.assertTrue(Login.objects.filter(pk=self.l2.pk).exists())
 
 
-class DeleteTests(TestCase):
+class OrderedDeleteTests(TestCase):
     def test_meta_ordered_delete(self):
         # When a subquery is performed by deletion code, the subquery must be
         # cleared of all ordering. There was a but that caused _meta ordering
@@ -331,49 +364,3 @@ class DeleteTests(TestCase):
         OrderedPerson.objects.create(name='Bob', lives_in=h)
         OrderedPerson.objects.filter(lives_in__address='Foo').delete()
         self.assertEqual(OrderedPerson.objects.count(), 0)
-
-    def test_foreign_key_delete_nullifies_correct_columns(self):
-        """
-        With a model (Researcher) that has two foreign keys pointing to the
-        same model (Contact), deleting an instance of the target model
-        (contact1) nullifies the correct fields of Researcher.
-        """
-        contact1 = Contact.objects.create(label='Contact 1')
-        contact2 = Contact.objects.create(label='Contact 2')
-        researcher1 = Researcher.objects.create(
-            primary_contact=contact1,
-            secondary_contact=contact2,
-        )
-        researcher2 = Researcher.objects.create(
-            primary_contact=contact2,
-            secondary_contact=contact1,
-        )
-        contact1.delete()
-        researcher1.refresh_from_db()
-        researcher2.refresh_from_db()
-        self.assertIsNone(researcher1.primary_contact)
-        self.assertEqual(researcher1.secondary_contact, contact2)
-        self.assertEqual(researcher2.primary_contact, contact2)
-        self.assertIsNone(researcher2.secondary_contact)
-
-    def test_self_reference_with_through_m2m_at_second_level(self):
-        toy = Toy.objects.create(name='Paints')
-        child = Child.objects.create(name='Juan')
-        Book.objects.create(pagecount=500, owner=child)
-        PlayedWith.objects.create(child=child, toy=toy, date=datetime.date.today())
-        Book.objects.filter(Exists(
-            Book.objects.filter(
-                pk=OuterRef('pk'),
-                owner__toys=toy.pk,
-            ),
-        )).delete()
-        self.assertIs(Book.objects.exists(), False)
-
-
-class DeleteDistinct(SimpleTestCase):
-    def test_disallowed_delete_distinct(self):
-        msg = 'Cannot call delete() after .distinct().'
-        with self.assertRaisesMessage(TypeError, msg):
-            Book.objects.distinct().delete()
-        with self.assertRaisesMessage(TypeError, msg):
-            Book.objects.distinct('id').delete()
