@@ -1,13 +1,14 @@
-from django.db import IntegrityError
-from django.db.models import ProtectedError, Q, Sum
-from django.forms.models import modelform_factory
+from django.db.models import Q
+from django.db.utils import IntegrityError
 from django.test import TestCase, skipIfDBFeature
+from django.forms.models import modelform_factory
+from django.db.models.deletion import ProtectedError
 
 from .models import (
-    A, Address, B, Board, C, Cafe, CharLink, Company, Contact, Content, D,
-    Developer, Guild, HasLinkThing, Link, Node, Note, OddRelation1,
-    OddRelation2, Organization, Person, Place, Related, Restaurant, Tag, Team,
-    TextLink,
+    Address, Place, Restaurant, Link, CharLink, TextLink,
+    Person, Contact, Note, Organization, OddRelation1, OddRelation2, Company,
+    Developer, Team, Guild, Tag, Board, HasLinkThing, A, B, C, D,
+    Related, Content, Node,
 )
 
 
@@ -15,8 +16,10 @@ class GenericRelationTests(TestCase):
 
     def test_inherited_models_content_type(self):
         """
-        GenericRelations on inherited classes use the correct content type.
+        Test that GenericRelations on inherited classes use the correct content
+        type.
         """
+
         p = Place.objects.create(name="South Park")
         r = Restaurant.objects.create(name="Chubby's")
         l1 = Link.objects.create(content_object=p)
@@ -26,7 +29,7 @@ class GenericRelationTests(TestCase):
 
     def test_reverse_relation_pk(self):
         """
-        The correct column name is used for the primary key on the
+        Test that the correct column name is used for the primary key on the
         originating model of a query.  See #12664.
         """
         p = Person.objects.create(account=23, name='Chef')
@@ -48,21 +51,12 @@ class GenericRelationTests(TestCase):
         TextLink.objects.create(content_object=oddrel)
         oddrel.delete()
 
-    def test_coerce_object_id_remote_field_cache_persistence(self):
-        restaurant = Restaurant.objects.create()
-        CharLink.objects.create(content_object=restaurant)
-        charlink = CharLink.objects.latest('pk')
-        self.assertIs(charlink.content_object, charlink.content_object)
-        # If the model (Cafe) uses more than one level of multi-table inheritance.
-        cafe = Cafe.objects.create()
-        CharLink.objects.create(content_object=cafe)
-        charlink = CharLink.objects.latest('pk')
-        self.assertIs(charlink.content_object, charlink.content_object)
-
     def test_q_object_or(self):
         """
-        SQL query parameters for generic relations are properly
-        grouped when OR is used (#11535).
+        Tests that SQL query parameters for generic relations are properly
+        grouped when OR is used.
+
+        Test for bug http://code.djangoproject.com/ticket/11535
 
         In this bug the first query (below) works while the second, with the
         query parameters the same but in reverse order, does not.
@@ -78,12 +72,12 @@ class GenericRelationTests(TestCase):
         # search with a non-matching note and a matching org name
         qs = Contact.objects.filter(Q(notes__note__icontains=r'other note') |
                                     Q(organizations__name__icontains=r'org name'))
-        self.assertIn(org_contact, qs)
+        self.assertTrue(org_contact in qs)
         # search again, with the same query parameters, in reverse order
         qs = Contact.objects.filter(
             Q(organizations__name__icontains=r'org name') |
             Q(notes__note__icontains=r'other note'))
-        self.assertIn(org_contact, qs)
+        self.assertTrue(org_contact in qs)
 
     def test_join_reuse(self):
         qs = Person.objects.filter(
@@ -95,7 +89,7 @@ class GenericRelationTests(TestCase):
 
     def test_generic_relation_ordering(self):
         """
-        Ordering over a generic relation does not include extraneous
+        Test that ordering over a generic relation does not include extraneous
         duplicate results, nor excludes rows not participating in the relation.
         """
         p1 = Place.objects.create(name="South Park")
@@ -105,7 +99,6 @@ class GenericRelationTests(TestCase):
         Link.objects.create(content_object=c)
 
         places = list(Place.objects.order_by('links__id'))
-
         def count_places(place):
             return len([p for p in places if p.id == place.id])
 
@@ -118,24 +111,25 @@ class GenericRelationTests(TestCase):
         # Fails with another, ORM-level error
         dev1 = Developer(name='Joe')
         note = Note(note='Deserves promotion', content_object=dev1)
-        with self.assertRaises(IntegrityError):
-            note.save()
+        self.assertRaises(IntegrityError, note.save)
 
     def test_target_model_len_zero(self):
-        """
-        Saving a model with a GenericForeignKey to a model instance whose
-        __len__ method returns 0 (Team.__len__() here) shouldn't fail (#13085).
-        """
+        """Test for #13085 -- __len__() returns 0"""
         team1 = Team.objects.create(name='Backend devs')
-        note = Note(note='Deserve a bonus', content_object=team1)
+        try:
+            note = Note(note='Deserve a bonus', content_object=team1)
+        except Exception as e:
+            if (issubclass(type(e), Exception) and
+                    str(e) == 'Impossible arguments to GFK.get_content_type!'):
+                self.fail("Saving model with GenericForeignKey to model instance whose "
+                          "__len__ method returns 0 shouldn't fail.")
+            raise e
         note.save()
 
-    def test_target_model_bool_false(self):
-        """
-        Saving a model with a GenericForeignKey to a model instance whose
-        __bool__ method returns False (Guild.__bool__() here) shouldn't fail
-        (#13085).
-        """
+    def test_target_model_nonzero_false(self):
+        """Test related to #13085"""
+        # __nonzero__() returns False -- This actually doesn't currently fail.
+        # This test validates that
         g1 = Guild.objects.create(name='First guild')
         note = Note(note='Note for guild', content_object=g1)
         note.save()
@@ -150,18 +144,22 @@ class GenericRelationTests(TestCase):
         tag.save()
 
     def test_ticket_20378(self):
-        # Create a couple of extra HasLinkThing so that the autopk value
-        # isn't the same for Link and HasLinkThing.
         hs1 = HasLinkThing.objects.create()
         hs2 = HasLinkThing.objects.create()
-        hs3 = HasLinkThing.objects.create()
-        hs4 = HasLinkThing.objects.create()
-        l1 = Link.objects.create(content_object=hs3)
-        l2 = Link.objects.create(content_object=hs4)
-        self.assertSequenceEqual(HasLinkThing.objects.filter(links=l1), [hs3])
-        self.assertSequenceEqual(HasLinkThing.objects.filter(links=l2), [hs4])
-        self.assertSequenceEqual(HasLinkThing.objects.exclude(links=l2), [hs1, hs2, hs3])
-        self.assertSequenceEqual(HasLinkThing.objects.exclude(links=l1), [hs1, hs2, hs4])
+        l1 = Link.objects.create(content_object=hs1)
+        l2 = Link.objects.create(content_object=hs2)
+        self.assertQuerysetEqual(
+            HasLinkThing.objects.filter(links=l1),
+            [hs1], lambda x: x)
+        self.assertQuerysetEqual(
+            HasLinkThing.objects.filter(links=l2),
+            [hs2], lambda x: x)
+        self.assertQuerysetEqual(
+            HasLinkThing.objects.exclude(links=l2),
+            [hs1], lambda x: x)
+        self.assertQuerysetEqual(
+            HasLinkThing.objects.exclude(links=l1),
+            [hs2], lambda x: x)
 
     def test_ticket_20564(self):
         b1 = B.objects.create()
@@ -172,8 +170,14 @@ class GenericRelationTests(TestCase):
         c3 = C.objects.create(b=b3)
         A.objects.create(flag=None, content_object=b1)
         A.objects.create(flag=True, content_object=b2)
-        self.assertSequenceEqual(C.objects.filter(b__a__flag=None), [c1, c3])
-        self.assertSequenceEqual(C.objects.exclude(b__a__flag=None), [c2])
+        self.assertQuerysetEqual(
+            C.objects.filter(b__a__flag=None),
+            [c1, c3], lambda x: x
+        )
+        self.assertQuerysetEqual(
+            C.objects.exclude(b__a__flag=None),
+            [c2], lambda x: x
+        )
 
     def test_ticket_20564_nullable_fk(self):
         b1 = B.objects.create()
@@ -186,10 +190,22 @@ class GenericRelationTests(TestCase):
         A.objects.create(flag=None, content_object=b1)
         A.objects.create(flag=True, content_object=b1)
         A.objects.create(flag=True, content_object=b2)
-        self.assertSequenceEqual(D.objects.exclude(b__a__flag=None), [d2])
-        self.assertSequenceEqual(D.objects.filter(b__a__flag=None), [d1, d3, d4])
-        self.assertSequenceEqual(B.objects.filter(a__flag=None), [b1, b3])
-        self.assertSequenceEqual(B.objects.exclude(a__flag=None), [b2])
+        self.assertQuerysetEqual(
+            D.objects.exclude(b__a__flag=None),
+            [d2], lambda x: x
+        )
+        self.assertQuerysetEqual(
+            D.objects.filter(b__a__flag=None),
+            [d1, d3, d4], lambda x: x
+        )
+        self.assertQuerysetEqual(
+            B.objects.filter(a__flag=None),
+            [b1, b3], lambda x: x
+        )
+        self.assertQuerysetEqual(
+            B.objects.exclude(a__flag=None),
+            [b2], lambda x: x
+        )
 
     def test_extra_join_condition(self):
         # A crude check that content_type_id is taken in account in the
@@ -201,39 +217,6 @@ class GenericRelationTests(TestCase):
         self.assertNotIn(" join ", str(B.objects.exclude(a__flag=True).query).lower())
         self.assertIn("content_type_id", str(B.objects.exclude(a__flag=True).query).lower())
 
-    def test_annotate(self):
-        hs1 = HasLinkThing.objects.create()
-        hs2 = HasLinkThing.objects.create()
-        HasLinkThing.objects.create()
-        b = Board.objects.create(name=str(hs1.pk))
-        Link.objects.create(content_object=hs2)
-        link = Link.objects.create(content_object=hs1)
-        Link.objects.create(content_object=b)
-        qs = HasLinkThing.objects.annotate(Sum('links')).filter(pk=hs1.pk)
-        # If content_type restriction isn't in the query's join condition,
-        # then wrong results are produced here as the link to b will also match
-        # (b and hs1 have equal pks).
-        self.assertEqual(qs.count(), 1)
-        self.assertEqual(qs[0].links__sum, link.id)
-        link.delete()
-        # Now if we don't have proper left join, we will not produce any
-        # results at all here.
-        # clear cached results
-        qs = qs.all()
-        self.assertEqual(qs.count(), 1)
-        # Note - 0 here would be a nicer result...
-        self.assertIs(qs[0].links__sum, None)
-        # Finally test that filtering works.
-        self.assertEqual(qs.filter(links__sum__isnull=True).count(), 1)
-        self.assertEqual(qs.filter(links__sum__isnull=False).count(), 0)
-
-    def test_filter_targets_related_pk(self):
-        HasLinkThing.objects.create()
-        hs2 = HasLinkThing.objects.create()
-        link = Link.objects.create(content_object=hs2)
-        self.assertNotEqual(link.object_id, link.pk)
-        self.assertSequenceEqual(HasLinkThing.objects.filter(links=link.pk), [hs2])
-
     def test_editable_generic_rel(self):
         GenericRelationForm = modelform_factory(HasLinkThing, fields='__all__')
         form = GenericRelationForm()
@@ -241,7 +224,7 @@ class GenericRelationTests(TestCase):
         form = GenericRelationForm({'links': None})
         self.assertTrue(form.is_valid())
         form.save()
-        links = HasLinkThing._meta.get_field('links')
+        links = HasLinkThing._meta.get_field_by_name('links')[0].field
         self.assertEqual(links.save_form_data_calls, 1)
 
     def test_ticket_22998(self):
@@ -253,31 +236,3 @@ class GenericRelationTests(TestCase):
         # where the pre_delete signal should fire and prevent deletion.
         with self.assertRaises(ProtectedError):
             related.delete()
-
-    def test_ticket_22982(self):
-        place = Place.objects.create(name='My Place')
-        self.assertIn('GenericRelatedObjectManager', str(place.links))
-
-    def test_filter_on_related_proxy_model(self):
-        place = Place.objects.create()
-        Link.objects.create(content_object=place)
-        self.assertEqual(Place.objects.get(link_proxy__object_id=place.id), place)
-
-    def test_generic_reverse_relation_with_mti(self):
-        """
-        Filtering with a reverse generic relation, where the GenericRelation
-        comes from multi-table inheritance.
-        """
-        place = Place.objects.create(name='Test Place')
-        link = Link.objects.create(content_object=place)
-        result = Link.objects.filter(places=place)
-        self.assertCountEqual(result, [link])
-
-    def test_generic_reverse_relation_with_abc(self):
-        """
-        The reverse generic relation accessor (targets) is created if the
-        GenericRelation comes from an abstract base model (HasLinks).
-        """
-        thing = HasLinkThing.objects.create()
-        link = Link.objects.create(content_object=thing)
-        self.assertCountEqual(link.targets.all(), [thing])
