@@ -1,15 +1,15 @@
+from __future__ import absolute_import
+
 import time
 
 from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpResponse
-from django.test import RequestFactory, SimpleTestCase, override_settings
-from django.test.utils import require_jinja2
-from django.urls import resolve
-from django.views.generic import RedirectView, TemplateView, View
+from django.test import TestCase, RequestFactory
+from django.utils import unittest
+from django.views.generic import View, TemplateView, RedirectView
 
 from . import views
 
-
 class SimpleView(View):
     """
     A simple view with a docstring.
@@ -40,7 +40,7 @@ class DecoratedDispatchView(SimpleView):
 
     @decorator
     def dispatch(self, request, *args, **kwargs):
-        return super().dispatch(request, *args, **kwargs)
+        return super(DecoratedDispatchView, self).dispatch(request, *args, **kwargs)
 
 
 class AboutTemplateView(TemplateView):
@@ -64,7 +64,7 @@ class InstanceView(View):
         return self
 
 
-class ViewTest(SimpleTestCase):
+class ViewTest(unittest.TestCase):
     rf = RequestFactory()
 
     def _assert_simple(self, response):
@@ -73,19 +73,23 @@ class ViewTest(SimpleTestCase):
 
     def test_no_init_kwargs(self):
         """
-        A view can't be accidentally instantiated before deployment
+        Test that a view can't be accidentally instantiated before deployment
         """
-        msg = 'This method is available only on the class, not on instances.'
-        with self.assertRaisesMessage(AttributeError, msg):
-            SimpleView(key='value').as_view()
+        try:
+            view = SimpleView(key='value').as_view()
+            self.fail('Should not be able to instantiate a view')
+        except AttributeError:
+            pass
 
     def test_no_init_args(self):
         """
-        A view can't be accidentally instantiated before deployment
+        Test that a view can't be accidentally instantiated before deployment
         """
-        msg = 'as_view() takes 1 positional argument but 2 were given'
-        with self.assertRaisesMessage(TypeError, msg):
-            SimpleView.as_view('value')
+        try:
+            view = SimpleView.as_view('value')
+            self.fail('Should not be able to use non-keyword arguments instantiating a view')
+        except TypeError:
+            pass
 
     def test_pathological_http_method(self):
         """
@@ -113,13 +117,6 @@ class ViewTest(SimpleTestCase):
         response = SimpleView.as_view()(self.rf.head('/'))
         self.assertEqual(response.status_code, 200)
 
-    def test_setup_get_and_head(self):
-        view_instance = SimpleView()
-        self.assertFalse(hasattr(view_instance, 'head'))
-        view_instance.setup(self.rf.get('/'))
-        self.assertTrue(hasattr(view_instance, 'head'))
-        self.assertEqual(view_instance.head, view_instance.get)
-
     def test_head_no_get(self):
         """
         Test a view which supplies no GET method responds to HEAD with HTTP 405.
@@ -139,28 +136,18 @@ class ViewTest(SimpleTestCase):
 
     def test_invalid_keyword_argument(self):
         """
-        View arguments must be predefined on the class and can't
+        Test that view arguments must be predefined on the class and can't
         be named like a HTTP method.
         """
-        msg = (
-            'The method name %s is not accepted as a keyword argument to '
-            'SimpleView().'
-        )
         # Check each of the allowed method names
         for method in SimpleView.http_method_names:
-            with self.assertRaisesMessage(TypeError, msg % method):
-                SimpleView.as_view(**{method: 'value'})
+            kwargs = dict(((method, "value"),))
+            self.assertRaises(TypeError, SimpleView.as_view, **kwargs)
 
         # Check the case view argument is ok if predefined on the class...
         CustomizableView.as_view(parameter="value")
         # ...but raises errors otherwise.
-        msg = (
-            "CustomizableView() received an invalid keyword 'foobar'. "
-            "as_view only accepts arguments that are already attributes of "
-            "the class."
-        )
-        with self.assertRaisesMessage(TypeError, msg):
-            CustomizableView.as_view(foobar="value")
+        self.assertRaises(TypeError, CustomizableView.as_view, foobar="value")
 
     def test_calling_more_than_once(self):
         """
@@ -172,7 +159,7 @@ class ViewTest(SimpleTestCase):
 
     def test_class_attributes(self):
         """
-        The callable returned from as_view() has proper
+        Test that the callable returned from as_view() has proper
         docstring, name and module.
         """
         self.assertEqual(SimpleView.__doc__, SimpleView.as_view().__doc__)
@@ -181,25 +168,25 @@ class ViewTest(SimpleTestCase):
 
     def test_dispatch_decoration(self):
         """
-        Attributes set by decorators on the dispatch method
+        Test that attributes set by decorators on the dispatch method
         are also present on the closure.
         """
         self.assertTrue(DecoratedDispatchView.as_view().is_decorated)
 
     def test_options(self):
         """
-        Views respond to HTTP OPTIONS requests with an Allow header
+        Test that views respond to HTTP OPTIONS requests with an Allow header
         appropriate for the methods implemented by the view class.
         """
         request = self.rf.options('/')
         view = SimpleView.as_view()
         response = view(request)
         self.assertEqual(200, response.status_code)
-        self.assertTrue(response.headers['Allow'])
+        self.assertTrue(response['Allow'])
 
     def test_options_for_get_view(self):
         """
-        A view implementing GET allows GET and HEAD.
+        Test that a view implementing GET allows GET and HEAD.
         """
         request = self.rf.options('/')
         view = SimpleView.as_view()
@@ -208,7 +195,7 @@ class ViewTest(SimpleTestCase):
 
     def test_options_for_get_and_post_view(self):
         """
-        A view implementing GET and POST allows GET, HEAD, and POST.
+        Test that a view implementing GET and POST allows GET, HEAD, and POST.
         """
         request = self.rf.options('/')
         view = SimplePostView.as_view()
@@ -217,7 +204,7 @@ class ViewTest(SimpleTestCase):
 
     def test_options_for_post_view(self):
         """
-        A view implementing POST allows POST.
+        Test that a view implementing POST allows POST.
         """
         request = self.rf.options('/')
         view = PostOnlyView.as_view()
@@ -226,7 +213,7 @@ class ViewTest(SimpleTestCase):
 
     def _assert_allows(self, response, *expected_methods):
         "Assert allowed HTTP methods reported in the Allow response header"
-        response_allows = set(response.headers['Allow'].split(', '))
+        response_allows = set(response['Allow'].split(', '))
         self.assertEqual(set(expected_methods + ('OPTIONS',)), response_allows)
 
     def test_args_kwargs_request_on_self(self):
@@ -240,60 +227,15 @@ class ViewTest(SimpleTestCase):
             self.assertNotIn(attribute, dir(bare_view))
             self.assertIn(attribute, dir(view))
 
-    def test_overridden_setup(self):
-        class SetAttributeMixin:
-            def setup(self, request, *args, **kwargs):
-                self.attr = True
-                super().setup(request, *args, **kwargs)
 
-        class CheckSetupView(SetAttributeMixin, SimpleView):
-            def dispatch(self, request, *args, **kwargs):
-                assert hasattr(self, 'attr')
-                return super().dispatch(request, *args, **kwargs)
-
-        response = CheckSetupView.as_view()(self.rf.get('/'))
-        self.assertEqual(response.status_code, 200)
-
-    def test_not_calling_parent_setup_error(self):
-        class TestView(View):
-            def setup(self, request, *args, **kwargs):
-                pass  # Not calling super().setup()
-
-        msg = (
-            "TestView instance has no 'request' attribute. Did you override "
-            "setup() and forget to call super()?"
-        )
-        with self.assertRaisesMessage(AttributeError, msg):
-            TestView.as_view()(self.rf.get('/'))
-
-    def test_setup_adds_args_kwargs_request(self):
-        request = self.rf.get('/')
-        args = ('arg 1', 'arg 2')
-        kwargs = {'kwarg_1': 1, 'kwarg_2': 'year'}
-
-        view = View()
-        view.setup(request, *args, **kwargs)
-        self.assertEqual(request, view.request)
-        self.assertEqual(args, view.args)
-        self.assertEqual(kwargs, view.kwargs)
-
-    def test_direct_instantiation(self):
-        """
-        It should be possible to use the view by directly instantiating it
-        without going through .as_view() (#21564).
-        """
-        view = PostOnlyView()
-        response = view.dispatch(self.rf.head('/'))
-        self.assertEqual(response.status_code, 405)
-
-
-@override_settings(ROOT_URLCONF='generic_views.urls')
-class TemplateViewTest(SimpleTestCase):
+class TemplateViewTest(TestCase):
+    urls = 'generic_views.urls'
 
     rf = RequestFactory()
 
     def _assert_about(self, response):
         response.render()
+        self.assertEqual(response.status_code, 200)
         self.assertContains(response, '<h1>About</h1>')
 
     def test_get(self):
@@ -325,27 +267,9 @@ class TemplateViewTest(SimpleTestCase):
 
     def test_template_name_required(self):
         """
-        A template view must provide a template name.
+        A template view must provide a template name
         """
-        msg = (
-            "TemplateResponseMixin requires either a definition of "
-            "'template_name' or an implementation of 'get_template_names()'"
-        )
-        with self.assertRaisesMessage(ImproperlyConfigured, msg):
-            self.client.get('/template/no_template/')
-
-    @require_jinja2
-    def test_template_engine(self):
-        """
-        A template view may provide a template engine.
-        """
-        request = self.rf.get('/using/')
-        view = TemplateView.as_view(template_name='generic_views/using.html')
-        self.assertEqual(view(request).render().content, b'DTL\n')
-        view = TemplateView.as_view(template_name='generic_views/using.html', template_engine='django')
-        self.assertEqual(view(request).render().content, b'DTL\n')
-        view = TemplateView.as_view(template_name='generic_views/using.html', template_engine='jinja2')
-        self.assertEqual(view(request).render().content, b'Jinja2\n')
+        self.assertRaises(ImproperlyConfigured, self.client.get, '/template/no_template/')
 
     def test_template_params(self):
         """
@@ -390,24 +314,11 @@ class TemplateViewTest(SimpleTestCase):
 
     def test_content_type(self):
         response = self.client.get('/template/content_type/')
-        self.assertEqual(response.headers['Content-Type'], 'text/plain')
-
-    def test_resolve_view(self):
-        match = resolve('/template/content_type/')
-        self.assertIs(match.func.view_class, TemplateView)
-        self.assertEqual(match.func.view_initkwargs['content_type'], 'text/plain')
-
-    def test_resolve_login_required_view(self):
-        match = resolve('/template/login_required/')
-        self.assertIs(match.func.view_class, TemplateView)
-
-    def test_extra_context(self):
-        response = self.client.get('/template/extra_context/')
-        self.assertEqual(response.context['title'], 'Title')
+        self.assertEqual(response['Content-Type'], 'text/plain')
 
 
-@override_settings(ROOT_URLCONF='generic_views.urls')
-class RedirectViewTest(SimpleTestCase):
+class RedirectViewTest(TestCase):
+    urls = 'generic_views.urls'
 
     rf = RequestFactory()
 
@@ -416,20 +327,14 @@ class RedirectViewTest(SimpleTestCase):
         response = RedirectView.as_view()(self.rf.get('/foo/'))
         self.assertEqual(response.status_code, 410)
 
-    def test_default_redirect(self):
-        "Default is a temporary redirect"
-        response = RedirectView.as_view(url='/bar/')(self.rf.get('/foo/'))
-        self.assertEqual(response.status_code, 302)
-        self.assertEqual(response.url, '/bar/')
-
     def test_permanent_redirect(self):
-        "Permanent redirects are an option"
-        response = RedirectView.as_view(url='/bar/', permanent=True)(self.rf.get('/foo/'))
+        "Default is a permanent redirect"
+        response = RedirectView.as_view(url='/bar/')(self.rf.get('/foo/'))
         self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
     def test_temporary_redirect(self):
-        "Temporary redirects are an option"
+        "Permanent redirects are an option"
         response = RedirectView.as_view(url='/bar/', permanent=False)(self.rf.get('/foo/'))
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, '/bar/')
@@ -437,97 +342,93 @@ class RedirectViewTest(SimpleTestCase):
     def test_include_args(self):
         "GET arguments can be included in the redirected URL"
         response = RedirectView.as_view(url='/bar/')(self.rf.get('/foo/'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
         response = RedirectView.as_view(url='/bar/', query_string=True)(self.rf.get('/foo/?pork=spam'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/?pork=spam')
 
     def test_include_urlencoded_args(self):
         "GET arguments can be URL-encoded when included in the redirected URL"
         response = RedirectView.as_view(url='/bar/', query_string=True)(
             self.rf.get('/foo/?unicode=%E2%9C%93'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/?unicode=%E2%9C%93')
 
     def test_parameter_substitution(self):
         "Redirection URLs can be parameterized"
         response = RedirectView.as_view(url='/bar/%(object_id)d/')(self.rf.get('/foo/42/'), object_id=42)
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/42/')
 
     def test_named_url_pattern(self):
         "Named pattern parameter should reverse to the matching pattern"
         response = RedirectView.as_view(pattern_name='artist_detail')(self.rf.get('/foo/'), pk=1)
-        self.assertEqual(response.status_code, 302)
-        self.assertEqual(response.headers['Location'], '/detail/artist/1/')
+        self.assertEqual(response.status_code, 301)
+        self.assertEqual(response['Location'], '/detail/artist/1/')
 
     def test_named_url_pattern_using_args(self):
         response = RedirectView.as_view(pattern_name='artist_detail')(self.rf.get('/foo/'), 1)
-        self.assertEqual(response.status_code, 302)
-        self.assertEqual(response.headers['Location'], '/detail/artist/1/')
+        self.assertEqual(response.status_code, 301)
+        self.assertEqual(response['Location'], '/detail/artist/1/')
+
+    def test_wrong_named_url_pattern(self):
+        "A wrong pattern name returns 410 GONE"
+        response = RedirectView.as_view(pattern_name='wrong.pattern_name')(self.rf.get('/foo/'))
+        self.assertEqual(response.status_code, 410)
 
     def test_redirect_POST(self):
-        "Default is a temporary redirect"
+        "Default is a permanent redirect"
         response = RedirectView.as_view(url='/bar/')(self.rf.post('/foo/'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
     def test_redirect_HEAD(self):
-        "Default is a temporary redirect"
+        "Default is a permanent redirect"
         response = RedirectView.as_view(url='/bar/')(self.rf.head('/foo/'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
     def test_redirect_OPTIONS(self):
-        "Default is a temporary redirect"
+        "Default is a permanent redirect"
         response = RedirectView.as_view(url='/bar/')(self.rf.options('/foo/'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
     def test_redirect_PUT(self):
-        "Default is a temporary redirect"
+        "Default is a permanent redirect"
         response = RedirectView.as_view(url='/bar/')(self.rf.put('/foo/'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
     def test_redirect_PATCH(self):
-        "Default is a temporary redirect"
+        "Default is a permanent redirect"
         response = RedirectView.as_view(url='/bar/')(self.rf.patch('/foo/'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
     def test_redirect_DELETE(self):
-        "Default is a temporary redirect"
+        "Default is a permanent redirect"
         response = RedirectView.as_view(url='/bar/')(self.rf.delete('/foo/'))
-        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, '/bar/')
 
     def test_redirect_when_meta_contains_no_query_string(self):
         "regression for #16705"
         # we can't use self.rf.get because it always sets QUERY_STRING
         response = RedirectView.as_view(url='/bar/')(self.rf.request(PATH_INFO='/foo/'))
-        self.assertEqual(response.status_code, 302)
-
-    def test_direct_instantiation(self):
-        """
-        It should be possible to use the view without going through .as_view()
-        (#21564).
-        """
-        view = RedirectView()
-        response = view.dispatch(self.rf.head('/foo/'))
-        self.assertEqual(response.status_code, 410)
+        self.assertEqual(response.status_code, 301)
 
 
-class GetContextDataTest(SimpleTestCase):
+class GetContextDataTest(unittest.TestCase):
 
     def test_get_context_data_super(self):
         test_view = views.CustomContextView()
         context = test_view.get_context_data(kwarg_test='kwarg_value')
 
         # the test_name key is inserted by the test classes parent
-        self.assertIn('test_name', context)
+        self.assertTrue('test_name' in context)
         self.assertEqual(context['kwarg_test'], 'kwarg_value')
         self.assertEqual(context['custom_key'], 'custom_value')
 
@@ -549,7 +450,7 @@ class GetContextDataTest(SimpleTestCase):
         self.assertEqual(context['object'], test_view.object)
 
 
-class UseMultipleObjectMixinTest(SimpleTestCase):
+class UseMultipleObjectMixinTest(unittest.TestCase):
     rf = RequestFactory()
 
     def test_use_queryset_from_view(self):
@@ -569,7 +470,7 @@ class UseMultipleObjectMixinTest(SimpleTestCase):
         self.assertEqual(context['object_list'], queryset)
 
 
-class SingleObjectTemplateResponseMixinTest(SimpleTestCase):
+class SingleObjectTemplateResponseMixinTest(unittest.TestCase):
 
     def test_template_mixin_without_template(self):
         """
@@ -578,9 +479,4 @@ class SingleObjectTemplateResponseMixinTest(SimpleTestCase):
         TemplateDoesNotExist.
         """
         view = views.TemplateResponseWithoutTemplate()
-        msg = (
-            "TemplateResponseMixin requires either a definition of "
-            "'template_name' or an implementation of 'get_template_names()'"
-        )
-        with self.assertRaisesMessage(ImproperlyConfigured, msg):
-            view.get_template_names()
+        self.assertRaises(ImproperlyConfigured, view.get_template_names)
