@@ -1,5 +1,5 @@
 """
-DB-API Shortcuts
+35. DB-API Shortcuts
 
 ``get_object_or_404()`` is a shortcut function to be used in view functions for
 performing a ``get()`` lookup and raising a ``Http404`` exception if a
@@ -11,25 +11,26 @@ performing a ``filter()`` lookup and raising a ``Http404`` exception if a
 """
 
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 
 
+@python_2_unicode_compatible
 class Author(models.Model):
     name = models.CharField(max_length=50)
 
+    def __str__(self):
+        return self.name
 
 class ArticleManager(models.Manager):
     def get_queryset(self):
-        return super().get_queryset().filter(authors__name__icontains='sir')
-
-
-class AttributeErrorManager(models.Manager):
-    def get_queryset(self):
-        raise AttributeError('AttributeErrorManager')
-
+        return super(ArticleManager, self).get_queryset().filter(authors__name__icontains='sir')
 
+@python_2_unicode_compatible
 class Article(models.Model):
     authors = models.ManyToManyField(Author)
     title = models.CharField(max_length=50)
     objects = models.Manager()
     by_a_sir = ArticleManager()
-    attribute_error_objects = AttributeErrorManager()
+
+    def __str__(self):
+        return self.title
