@@ -5,7 +5,6 @@ import io
 import os
 import re
 import shutil
-import sys
 import warnings
 
 from django.core import management
@@ -15,7 +14,7 @@ from django.utils._os import upath
 from django.utils import six
 from django.utils.six import StringIO
 from django.utils.translation import TranslatorCommentWarning
-from django.utils.unittest import expectedFailure, SkipTest
+from django.utils.unittest import SkipTest
 
 
 LOCALE='de'
@@ -142,10 +141,6 @@ class BasicExtractorTests(ExtractorTests):
         self.assertIn("UnicodeDecodeError: skipped file not_utf8.txt in .",
                       force_text(stdout.getvalue()))
 
-    # This issue is fixed in 1.8+ (#23312).
-    if six.PY3 and sys.platform.startswith('win'):
-        test_unicode_decode_error = expectedFailure(test_unicode_decode_error)
-
     def test_extraction_warning(self):
         """test xgettext warning about multiple bare interpolation placeholders"""
         os.chdir(self.test_dir)
