@@ -1,17 +1,17 @@
-import unittest
+from __future__ import absolute_import
 
-from django.test import TestCase
+from django.utils import unittest
 
-from .models import PersonWithCustomMaxLengths, PersonWithDefaultMaxLengths
+from .models import PersonWithDefaultMaxLengths, PersonWithCustomMaxLengths
 
 
 class MaxLengthArgumentsTests(unittest.TestCase):
 
-    def verify_max_length(self, model, field, length):
-        self.assertEqual(model._meta.get_field(field).max_length, length)
+    def verify_max_length(self, model,field,length):
+        self.assertEqual(model._meta.get_field(field).max_length,length)
 
     def test_default_max_lengths(self):
-        self.verify_max_length(PersonWithDefaultMaxLengths, 'email', 254)
+        self.verify_max_length(PersonWithDefaultMaxLengths, 'email', 75)
         self.verify_max_length(PersonWithDefaultMaxLengths, 'vcard', 100)
         self.verify_max_length(PersonWithDefaultMaxLengths, 'homepage', 200)
         self.verify_max_length(PersonWithDefaultMaxLengths, 'avatar', 100)
@@ -22,8 +22,7 @@ class MaxLengthArgumentsTests(unittest.TestCase):
         self.verify_max_length(PersonWithCustomMaxLengths, 'homepage', 250)
         self.verify_max_length(PersonWithCustomMaxLengths, 'avatar', 250)
 
-
-class MaxLengthORMTests(TestCase):
+class MaxLengthORMTests(unittest.TestCase):
 
     def test_custom_max_lengths(self):
         args = {
@@ -35,6 +34,6 @@ class MaxLengthORMTests(TestCase):
 
         for field in ("email", "vcard", "homepage", "avatar"):
             new_args = args.copy()
-            new_args[field] = "X" * 250  # a value longer than any of the default fields could hold.
+            new_args[field] = "X" * 250 # a value longer than any of the default fields could hold.
             p = PersonWithCustomMaxLengths.objects.create(**new_args)
-            self.assertEqual(getattr(p, field), ("X" * 250))
+            self.assertEqual(getattr(p, field), ("X" * 250))
\ No newline at end of file
