@@ -1,26 +1,22 @@
-import copy
+from __future__ import absolute_import, unicode_literals
+
 import datetime
 from operator import attrgetter
+import sys
 
 from django.core.exceptions import ValidationError
-from django.db import models, router
-from django.db.models.sql import InsertQuery
 from django.test import TestCase, skipUnlessDBFeature
-from django.test.utils import isolate_apps
-from django.utils.timezone import get_fixed_timezone
+from django.utils import six
+from django.utils import tzinfo
+from django.utils import unittest
+from django.db import connection, router
+from django.db.models.sql import InsertQuery
 
-from .models import (
-    Article, Department, Event, Model1, Model2, Model3, NonAutoPK, Party,
-    Worker,
-)
+from .models import (Worker, Article, Party, Event, Department,
+    BrokenUnicodeMethod, NonAutoPK, Model1, Model2, Model3)
 
 
 class ModelTests(TestCase):
-    def test_model_init_too_many_args(self):
-        msg = "Number of args exceeds number of fields"
-        with self.assertRaisesMessage(IndexError, msg):
-            Worker(1, 2, 3, 4)
-
     # The bug is that the following queries would raise:
     # "TypeError: Related Field has invalid lookup: gte"
     def test_related_gte_lookup(self):
@@ -54,9 +50,10 @@ class ModelTests(TestCase):
         # An empty choice field should return None for the display name.
         self.assertIs(a.get_status_display(), None)
 
-        # Empty strings should be returned as string
+        # Empty strings should be returned as Unicode
         a = Article.objects.get(pk=a.pk)
         self.assertEqual(a.misc_data, '')
+        self.assertIs(type(a.misc_data), six.text_type)
 
     def test_long_textfield(self):
         # TextFields can hold more than 4000 characters (this was broken in
@@ -69,17 +66,6 @@ class ModelTests(TestCase):
         a = Article.objects.get(pk=a.pk)
         self.assertEqual(len(a.article_text), 5000)
 
-    def test_long_unicode_textfield(self):
-        # TextFields can hold more than 4000 bytes also when they are
-        # less than 4000 characters
-        a = Article.objects.create(
-            headline="Really, really big",
-            pub_date=datetime.datetime.now(),
-            article_text='\u05d0\u05d1\u05d2' * 1000
-        )
-        a = Article.objects.get(pk=a.pk)
-        self.assertEqual(len(a.article_text), 3000)
-
     def test_date_lookup(self):
         # Regression test for #659
         Party.objects.create(when=datetime.datetime(1999, 12, 31))
@@ -135,21 +121,26 @@ class ModelTests(TestCase):
 
         # Regression test for #18969
         self.assertQuerysetEqual(
-            Party.objects.filter(when__year=1), [
-                datetime.date(1, 3, 3),
-            ],
-            attrgetter("when")
+                Party.objects.filter(when__year=1), [
+                        datetime.date(1, 3, 3),
+                    ],
+                attrgetter("when")
         )
         self.assertQuerysetEqual(
-            Party.objects.filter(when__year='1'), [
-                datetime.date(1, 3, 3),
-            ],
-            attrgetter("when")
-        )
+                Party.objects.filter(when__year='1'), [
+                        datetime.date(1, 3, 3),
+                    ],
+                attrgetter("when")
+       )
+
+    if (3,) <= sys.version_info < (3, 3) and connection.vendor == 'mysql':
+        # In Python < 3.3, datetime.strftime raises an exception for years
+        # below 1000, and existing MySQL DB-API drivers hit this problem.
+        test_date_lookup = unittest.expectedFailure(test_date_lookup)
 
     def test_date_filter_null(self):
         # Date filtering was failing with NULL date values in SQLite
-        # (regression test for #3501, among other things).
+        # (regression test for #3501, amongst other things).
         Party.objects.create(when=datetime.datetime(1999, 1, 1))
         Party.objects.create()
         p = Party.objects.filter(when__month=1)[0]
@@ -162,12 +153,18 @@ class ModelTests(TestCase):
         )
 
     def test_get_next_prev_by_field(self):
-        # get_next_by_FIELD() and get_previous_by_FIELD() don't crash when
-        # microseconds values are stored in the database.
+        # Check that get_next_by_FIELD and get_previous_by_FIELD don't crash
+        # when we have usecs values stored on the database
+        #
+        # It crashed after the Field.get_db_prep_* refactor, because on most
+        # backends DateTimeFields supports usecs, but DateTimeField.to_python
+        # didn't recognize them. (Note that
+        # Model._get_next_or_previous_by_FIELD coerces values to strings)
         Event.objects.create(when=datetime.datetime(2000, 1, 1, 16, 0, 0))
         Event.objects.create(when=datetime.datetime(2000, 1, 1, 6, 1, 1))
         Event.objects.create(when=datetime.datetime(2000, 1, 1, 13, 1, 1))
         e = Event.objects.create(when=datetime.datetime(2000, 1, 1, 12, 0, 20, 24))
+
         self.assertEqual(
             e.get_next_by_when().when, datetime.datetime(2000, 1, 1, 13, 1, 1)
         )
@@ -175,27 +172,25 @@ class ModelTests(TestCase):
             e.get_previous_by_when().when, datetime.datetime(2000, 1, 1, 6, 1, 1)
         )
 
-    def test_get_next_prev_by_field_unsaved(self):
-        msg = 'get_next/get_previous cannot be used on unsaved objects.'
-        with self.assertRaisesMessage(ValueError, msg):
-            Event().get_next_by_when()
-        with self.assertRaisesMessage(ValueError, msg):
-            Event().get_previous_by_when()
-
     def test_primary_key_foreign_key_types(self):
         # Check Department and Worker (non-default PK type)
         d = Department.objects.create(id=10, name="IT")
         w = Worker.objects.create(department=d, name="Full-time")
-        self.assertEqual(str(w), "Full-time")
+        self.assertEqual(six.text_type(w), "Full-time")
+
+    def test_broken_unicode(self):
+        # Models with broken unicode methods should still have a printable repr
+        b = BrokenUnicodeMethod.objects.create(name="Jerry")
+        self.assertEqual(repr(b), "<BrokenUnicodeMethod: [Bad Unicode data]>")
 
     @skipUnlessDBFeature("supports_timezones")
     def test_timezones(self):
-        # Saving and updating with timezone-aware datetime Python objects.
+        # Saving an updating with timezone-aware datetime Python objects.
         # Regression test for #10443.
         # The idea is that all these creations and saving should work without
         # crashing. It's not rocket science.
-        dt1 = datetime.datetime(2008, 8, 31, 16, 20, tzinfo=get_fixed_timezone(600))
-        dt2 = datetime.datetime(2008, 8, 31, 17, 20, tzinfo=get_fixed_timezone(600))
+        dt1 = datetime.datetime(2008, 8, 31, 16, 20, tzinfo=tzinfo.FixedOffset(600))
+        dt2 = datetime.datetime(2008, 8, 31, 17, 20, tzinfo=tzinfo.FixedOffset(600))
         obj = Article.objects.create(
             headline="A headline", pub_date=dt1, article_text="foo"
         )
@@ -219,30 +214,12 @@ class ModelTests(TestCase):
         m3 = Model3.objects.get(model2=1000)
         m3.model2
 
-    @isolate_apps('model_regress')
-    def test_metaclass_can_access_attribute_dict(self):
-        """
-        Model metaclasses have access to the class attribute dict in
-        __init__() (#30254).
-        """
-        class HorseBase(models.base.ModelBase):
-            def __init__(cls, name, bases, attrs):
-                super(HorseBase, cls).__init__(name, bases, attrs)
-                cls.horns = (1 if 'magic' in attrs else 0)
-
-        class Horse(models.Model, metaclass=HorseBase):
-            name = models.CharField(max_length=255)
-            magic = True
-
-        self.assertEqual(Horse.horns, 1)
-
 
 class ModelValidationTest(TestCase):
     def test_pk_validation(self):
-        NonAutoPK.objects.create(name="one")
+        one = NonAutoPK.objects.create(name="one")
         again = NonAutoPK(name="one")
-        with self.assertRaises(ValidationError):
-            again.validate_unique()
+        self.assertRaises(ValidationError, again.validate_unique)
 
 
 class EvaluateMethodTest(TestCase):
@@ -252,22 +229,8 @@ class EvaluateMethodTest(TestCase):
 
     def test_model_with_evaluate_method(self):
         """
-        You can filter by objects that have an 'evaluate' attr
+        Ensures that you can filter by objects that have an 'evaluate' attr
         """
         dept = Department.objects.create(pk=1, name='abc')
         dept.evaluate = 'abc'
         Worker.objects.filter(department=dept)
-
-
-class ModelFieldsCacheTest(TestCase):
-    def test_fields_cache_reset_on_copy(self):
-        department1 = Department.objects.create(id=1, name='department1')
-        department2 = Department.objects.create(id=2, name='department2')
-        worker1 = Worker.objects.create(name='worker', department=department1)
-        worker2 = copy.copy(worker1)
-
-        self.assertEqual(worker2.department, department1)
-        # Changing related fields doesn't mutate the base object.
-        worker2.department = department2
-        self.assertEqual(worker2.department, department2)
-        self.assertEqual(worker1.department, department1)
