@@ -1,6 +1,8 @@
-from django.test import TestCase
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, unicode_literals
 
-from .models import Article, Bar, Base, Child, Foo, Whiz
+from django.test import TestCase
+from .models import Foo, Whiz, Bar, Article, Base, Child
 
 
 class StringLookupTests(TestCase):
@@ -9,8 +11,8 @@ class StringLookupTests(TestCase):
         """
         Regression test for #1661 and #1662
 
-        String form referencing of models works, both as pre and post
-        reference, on all RelatedField types.
+        Check that string form referencing of
+        models works, both as pre and post reference, on all RelatedField types.
         """
 
         f1 = Foo(name="Foo1")
@@ -51,6 +53,9 @@ class StringLookupTests(TestCase):
         fx.save()
         self.assertEqual(Foo.objects.get(friend__contains='\xe7'), fx)
 
+        # We can also do the above query using UTF-8 strings.
+        self.assertEqual(Foo.objects.get(friend__contains=b'\xc3\xa7'), fx)
+
     def test_queries_on_textfields(self):
         """
         Regression tests for #5087
@@ -72,6 +77,7 @@ class StringLookupTests(TestCase):
         """
         a = Article(name='IP test', text='The body', submitted_from='192.0.2.100')
         a.save()
-        self.assertSequenceEqual(Article.objects.filter(submitted_from__contains='192.0.2'), [a])
-        # The searches do not match the subnet mask (/32 in this case)
-        self.assertEqual(Article.objects.filter(submitted_from__contains='32').count(), 0)
+        self.assertEqual(repr(Article.objects.filter(submitted_from__contains='192.0.2')),
+            repr([a]))
+        # Test that the searches do not match the subnet mask (/32 in this case)
+        self.assertEqual(Article.objects.filter(submitted_from__contains='32').count(), 0)
\ No newline at end of file
